Module batch

Module batch 

Batch execution and query partitioning support. Re-exports for Spanner batch execution and query partitioning.

Structs

BatchDml
A batch of DML statements to be executed in a single round-trip to Spanner.
BatchReadOnlyTransaction
A read-only transaction that can be used to partition reads and queries and execute these in parallel across multiple workers.
BatchWriteResponseStream
A stream of BatchWriteResponse messages.
BatchWriteTransaction
A transaction for executing batch writes.
Partition
Defines the segments of data to be read in a partitioned read or query. These partitions can be serialized and processed across several different machines or processes.