pub struct BatchReadOnlyTransaction { /* private fields */ }Expand description
A read-only transaction that can be used to partition reads and queries and execute these in parallel across multiple workers.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.batch_read_only_transaction().build().await?;
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let options = PartitionOptions::default()
.set_max_partitions(10);
let partitions = transaction.partition_query(stmt, options).await?;
// partitions can be sent to other workers for parallel executionImplementations
Sourceimpl BatchReadOnlyTransaction
impl BatchReadOnlyTransaction
Sourcepub fn read_timestamp(&self) -> Option<Timestamp>
pub fn read_timestamp(&self) -> Option<Timestamp>
Returns the read timestamp chosen for the transaction.
Sourcepub async fn partition_query<T: Into<Statement>>(
&self,
statement: T,
options: PartitionOptions,
) -> Result<Vec<Partition>>
pub async fn partition_query<T: Into<Statement>>( &self, statement: T, options: PartitionOptions, ) -> Result<Vec<Partition>>
Creates a set of partitions that can be used to execute a query in parallel.
Example
let db = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db.batch_read_only_transaction().build().await?;
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let options = PartitionOptions::default()
.set_max_partitions(10);
let partitions = transaction.partition_query(stmt, options).await?;Sourcepub async fn partition_read<T: Into<ReadRequest>>(
&self,
read: T,
options: PartitionOptions,
) -> Result<Vec<Partition>>
pub async fn partition_read<T: Into<ReadRequest>>( &self, read: T, options: PartitionOptions, ) -> Result<Vec<Partition>>
Creates a set of partitions that can be used to execute a read in parallel.
Example
let db = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db.batch_read_only_transaction().build().await?;
let read = ReadRequest::builder("users", vec!["id".to_string(), "name".to_string()])
.with_keys(KeySet::all())
.build();
let options = PartitionOptions::default()
.set_max_partitions(10);
let partitions = transaction.partition_read(read, options).await?;Trait Implementations