pub struct Partition { /* private fields */ }Expand description
Defines the segments of data to be read in a partitioned read or query. These partitions can be serialized and processed across several different machines or processes.
Implementations
Sourceimpl Partition
impl Partition
Sourcepub fn set_data_boost(self, enabled: bool) -> Self
pub fn set_data_boost(self, enabled: bool) -> Self
Sets whether Data Boost is enabled for this partition.
Example
// On a worker receiving a partition, execute it with Data Boost:
let mut result_set = partitions[0].clone()
.set_data_boost(true)
.execute(&db_client)
.await?;Sourcepub fn with_attempt_timeout(self, timeout: Duration) -> Self
pub fn with_attempt_timeout(self, timeout: Duration) -> Self
Sets the per-attempt timeout for this partition execution.
Note: This field is not serialized. Each host that executes a partition must set its own attempt timeout.
Sourcepub fn with_retry_policy(self, policy: impl Into<RetryPolicyArg>) -> Self
pub fn with_retry_policy(self, policy: impl Into<RetryPolicyArg>) -> Self
Sets the retry policy for this partition execution.
Note: This field is not serialized. Each host that executes a partition must set its own retry policy.
Sourcepub fn with_backoff_policy(self, policy: impl Into<BackoffPolicyArg>) -> Self
pub fn with_backoff_policy(self, policy: impl Into<BackoffPolicyArg>) -> Self
Sets the backoff policy for this partition execution.
Note: This field is not serialized. Each host that executes a partition must set its own backoff policy.
Sourcepub async fn execute(&self, client: &DatabaseClient) -> Result<ResultSet>
pub async fn execute(&self, client: &DatabaseClient) -> Result<ResultSet>
Executes this partition and returns a ResultSet that contains the rows that belong to this partition.
Example: executing a query partition
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.batch_read_only_transaction().build().await?;
let partitions = transaction.partition_query(
Statement::builder("SELECT * FROM Users").build(),
PartitionOptions::default()
).await?;
// ... send partitions to other workers ...
// On a worker receiving a partition, execute it:
let mut result_set = partitions[0].execute(&db_client).await?;
while let Some(row) = result_set.next().await.transpose()? {
// process row
}Example: executing a read partition
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.batch_read_only_transaction().build().await?;
let req = ReadRequest::builder("Users", vec!["Id", "Name"]).with_keys(KeySet::all()).build();
let partitions = transaction.partition_read(req, PartitionOptions::default()).await?;
// ... send partitions to other workers ...
// On a worker receiving a partition, execute it:
let mut result_set = partitions[0].execute(&db_client).await?;
while let Some(row) = result_set.next().await.transpose()? {
// process row
}A partition can be executed by any DatabaseClient that is connected to
the database that the partitions belong to.