pub struct SingleUseReadOnlyTransactionBuilder { /* private fields */ }Expand description
A builder for SingleUseReadOnlyTransaction.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let read_only_tx = db_client.single_use()
.set_timestamp_bound(TimestampBound::strong())
.build();Implementations
Sourceimpl SingleUseReadOnlyTransactionBuilder
impl SingleUseReadOnlyTransactionBuilder
Sourcepub fn set_timestamp_bound(self, bound: TimestampBound) -> Self
pub fn set_timestamp_bound(self, bound: TimestampBound) -> Self
Sets the timestamp bound for the read-only transaction.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let builder = db_client.single_use().set_timestamp_bound(TimestampBound::strong());When reading data in Spanner in a read-only transaction, you can set a timestamp bound, which tells Spanner how to choose a timestamp at which to read the data.
See https://docs.cloud.google.com/spanner/docs/timestamp-bounds for more information.
Sourcepub fn build(self) -> SingleUseReadOnlyTransaction
pub fn build(self) -> SingleUseReadOnlyTransaction
Builds the SingleUseReadOnlyTransaction.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db_client.single_use().build();Auto Trait Implementations
impl !RefUnwindSafe for SingleUseReadOnlyTransactionBuilder
impl !UnwindSafe for SingleUseReadOnlyTransactionBuilder
impl Freeze for SingleUseReadOnlyTransactionBuilder
impl Send for SingleUseReadOnlyTransactionBuilder
impl Sync for SingleUseReadOnlyTransactionBuilder
impl Unpin for SingleUseReadOnlyTransactionBuilder
impl UnsafeUnpin for SingleUseReadOnlyTransactionBuilder