Module error

Module error 

Crate error types.

Structs

BatchUpdateError
An error that occurs when an execute_batch_update partially succeeds.

Enums

ConvertError
Represent failures in converting a Spanner Value to a Rust type.
DurationError
Represent failures in converting or creating Duration instances.
SpannerInternalError
An unexpected error that occurs when the client receives data from Spanner that it cannot properly parse or handle. This typically indicates a bug in the client library or the Spanner service itself, though other causes are possible.
TimestampError
Represent failures in converting or creating Timestamp instances.