#[non_exhaustive]pub enum ConvertError {
KindMismatch {
want: Kind,
got: Kind,
},
NotNull,
Convert(Box<dyn Error + Send + Sync>),
}Expand description
Represent failures in converting a Spanner Value to a Rust type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KindMismatch
The value kind is not as expected.
NotNull
The value is null, but the target type does not support nulls.
Convert(Box<dyn Error + Send + Sync>)
There was a problem during conversion.