BatchUpdateError

Struct BatchUpdateError 

#[non_exhaustive]
pub struct BatchUpdateError { pub update_counts: Vec<i64>, pub status: Error, }
An error that occurs when an execute_batch_update partially succeeds.

It contains the update counts for each statement evaluated prior to the failure, as well as the underlying error that caused the batch to fail.

Statements are executed serially in the order provided in the batch. The update_counts correspond to the executed statements in the original request based on their relative order. The statement that failed is the one that follows directly after the last statement with an update count. Execution stops at the first failed statement, and the remaining statements are not executed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
update_counts: Vec<i64>

The number of rows modified by each successful statement before the failure.

status: Error

The error that caused the batch to fail.

Implementations

Source

impl BatchUpdateError

pub fn extract(err: &Error) -> Option<&Self>

Extracts a BatchUpdateError from a google_cloud_spanner::Error, if present.