pub struct KeySet { /* private fields */ }Expand description
A collection of Spanner keys and key ranges.
Example
use google_cloud_spanner::key::KeySet;
use google_cloud_spanner::key::KeyRange;
use google_cloud_spanner::key;
let keyset = KeySet::builder()
.add_key(key![1_i64])
.add_range(KeyRange::closed_open(key![10_i64], key![100_i64]))
.build();Defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way.
KeySets are used for delete mutations and reads.
If the same key is specified multiple times in the set (for example if two ranges, two keys,
or a key and a range overlap), the Cloud Spanner backend behaves as if the key were only
specified once. KeySet instances are immutable.
Implementations