Module model

Module model 

The messages and enums that are part of this client library.

Modules

batch_write_request
Defines additional types related to BatchWriteRequest.
change_stream_record
Defines additional types related to ChangeStreamRecord.
commit_request
Defines additional types related to CommitRequest.
commit_response
Defines additional types related to CommitResponse.
directed_read_options
Defines additional types related to DirectedReadOptions.
execute_batch_dml_request
Defines additional types related to ExecuteBatchDmlRequest.
execute_sql_request
Defines additional types related to ExecuteSqlRequest.
key_range
Defines additional types related to KeyRange.
key_recipe
Defines additional types related to KeyRecipe.
mutation
Defines additional types related to Mutation.
plan_node
Defines additional types related to PlanNode.
query_advisor_result
Defines additional types related to QueryAdvisorResult.
read_request
Defines additional types related to ReadRequest.
request_options
Defines additional types related to RequestOptions.
result_set_stats
Defines additional types related to ResultSetStats.
routing_hint
Defines additional types related to RoutingHint.
struct_type
Defines additional types related to StructType.
tablet
Defines additional types related to Tablet.
transaction_options
Defines additional types related to TransactionOptions.
transaction_selector
Defines additional types related to TransactionSelector.

Structs

BatchCreateSessionsRequest
The request for BatchCreateSessions.
BatchCreateSessionsResponse
The response for BatchCreateSessions.
BatchWriteRequest
The request for [BatchWrite][google.spanner.v1.Spanner.BatchWrite].
BatchWriteResponse
The result of applying a batch of mutations.
BeginTransactionRequest
The request for BeginTransaction.
CacheUpdate
A CacheUpdate expresses a set of changes the client should incorporate into its location cache. These changes may or may not be newer than what the client has in its cache, and should be discarded if necessary. CacheUpdates can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.
ChangeStreamRecord
Spanner Change Streams enable customers to capture and stream out changes to their Spanner databases in real-time. A change stream can be created with option partition_mode=‘IMMUTABLE_KEY_RANGE’ or partition_mode=‘MUTABLE_KEY_RANGE’.
CommitRequest
The request for Commit.
CommitResponse
The response for Commit.
CreateSessionRequest
The request for CreateSession.
DeleteSessionRequest
The request for DeleteSession.
DirectedReadOptions
The DirectedReadOptions can be used to indicate which replicas or regions should be used for non-transactional reads or queries.
ExecuteBatchDmlRequest
The request for ExecuteBatchDml.
ExecuteBatchDmlResponse
The response for ExecuteBatchDml. Contains a list of ResultSet messages, one for each DML statement that has successfully executed, in the same order as the statements in the request. If a statement fails, the status in the response body identifies the cause of the failure.
ExecuteSqlRequest
The request for ExecuteSql and [ExecuteStreamingSql][google.spanner.v1.Spanner.ExecuteStreamingSql].
FetchCacheUpdateRequest
The request for [FetchCacheUpdate][google.spanner.v1.Spanner.FetchCacheUpdate].
GetSessionRequest
The request for GetSession.
Group
A Group represents a paxos group in a database. A group is a set of tablets that are replicated across multiple servers. Groups may have a leader tablet. Groups store one (or sometimes more) ranges of keys.
KeyRange
KeyRange represents a range of rows in a table or index.
KeyRecipe
A KeyRecipe provides the metadata required to translate reads, mutations, and queries into a byte array in “sortable string format” (ssformat)that can be used with Ranges to route requests. Note that the client must tolerate KeyRecipes that appear to be invalid, since the KeyRecipe format may change over time. Requests with invalid KeyRecipes should be routed to a default server.
KeySet
KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way.
ListSessionsRequest
The request for ListSessions.
ListSessionsResponse
The response for ListSessions.
MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
Mutation
A modification to one or more Cloud Spanner rows. Mutations can be applied to a Cloud Spanner database by sending them in a Commit call.
PartialResultSet
Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.
Partition
Information returned for each partition returned in a PartitionResponse.
PartitionOptions
Options for a PartitionQueryRequest and PartitionReadRequest.
PartitionQueryRequest
The request for PartitionQuery
PartitionReadRequest
The request for PartitionRead
PartitionResponse
The response for PartitionQuery or PartitionRead
PlanNode
Node information for nodes appearing in a QueryPlan.plan_nodes.
QueryAdvisorResult
Output of query advisor analysis.
QueryPlan
Contains an ordered list of nodes appearing in the query plan.
Range
A Range represents a range of keys in a database. The keys themselves are encoded in “sortable string format”, also known as ssformat. Consult Spanner’s open source client libraries for details on the encoding.
ReadRequest
The request for Read and [StreamingRead][google.spanner.v1.Spanner.StreamingRead].
RecipeList
A RecipeList contains a list of KeyRecipes, which share the same schema generation.
RequestOptions
Common request options for various APIs.
ResultSet
Results from Read or ExecuteSql.
ResultSetMetadata
Metadata about a ResultSet or PartialResultSet.
ResultSetStats
Additional statistics about a ResultSet or PartialResultSet.
RollbackRequest
The request for Rollback.
RoutingHint
RoutingHint can be optionally added to location-aware Spanner requests. It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.
Session
A session in the Cloud Spanner API.
StructType
StructType defines the fields of a STRUCT type.
Tablet
A Tablet represents a single replica of a Group. A tablet is served by a single server at a time, and can move between servers due to server death or simply load balancing.
Transaction
A transaction.
TransactionOptions
Options to use for transactions.
TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql call runs.
Type
Type indicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query.

Enums

TypeAnnotationCode
TypeAnnotationCode is used as a part of Type to disambiguate SQL types that should be used for a given Cloud Spanner value. Disambiguation is needed because the same Cloud Spanner type can be mapped to different SQL types depending on SQL dialect. TypeAnnotationCode doesn’t affect the way value is serialized.
TypeCode
TypeCode is used as part of Type to indicate the type of a Cloud Spanner value.