Module batch_write_request

Module batch_write_request 

Defines additional types related to BatchWriteRequest.

Structs

MutationGroup
A group of mutations to be committed together. Related mutations should be placed in a group. For example, two mutations inserting rows with the same primary key prefix in both parent and child tables are related.