#[non_exhaustive]pub struct MutationGroup {
pub mutations: Vec<Mutation>,
/* private fields */
}Expand description
A group of mutations to be committed together. Related mutations should be placed in a group. For example, two mutations inserting rows with the same primary key prefix in both parent and child tables are related.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mutations: Vec<Mutation>Required. The mutations in this group.
Implementations
Sourceimpl MutationGroup
impl MutationGroup
Sourcepub fn set_mutations<T, V>(self, v: T) -> Self
pub fn set_mutations<T, V>(self, v: T) -> Self
Sets the value of mutations.