#[non_exhaustive]pub enum Record {
DataChangeRecord(Box<DataChangeRecord>),
HeartbeatRecord(Box<HeartbeatRecord>),
PartitionStartRecord(Box<PartitionStartRecord>),
PartitionEndRecord(Box<PartitionEndRecord>),
PartitionEventRecord(Box<PartitionEventRecord>),
}Expand description
One of the change stream subrecords.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DataChangeRecord(Box<DataChangeRecord>)
Data change record describing a data change for a change stream partition.
HeartbeatRecord(Box<HeartbeatRecord>)
Heartbeat record describing a heartbeat for a change stream partition.
PartitionStartRecord(Box<PartitionStartRecord>)
Partition start record describing a new change stream partition.
PartitionEndRecord(Box<PartitionEndRecord>)
Partition end record describing a terminated change stream partition.
PartitionEventRecord(Box<PartitionEventRecord>)
Partition event record describing key range changes for a change stream partition.
Implementations
Sourceimpl Record
impl Record
Sourcepub fn from_data_change_record(value: impl Into<Box<DataChangeRecord>>) -> Self
pub fn from_data_change_record(value: impl Into<Box<DataChangeRecord>>) -> Self
Initializes the enum to the DataChangeRecord branch.
Sourcepub fn from_heartbeat_record(value: impl Into<Box<HeartbeatRecord>>) -> Self
pub fn from_heartbeat_record(value: impl Into<Box<HeartbeatRecord>>) -> Self
Initializes the enum to the HeartbeatRecord branch.
Sourcepub fn from_partition_start_record(
value: impl Into<Box<PartitionStartRecord>>,
) -> Self
pub fn from_partition_start_record( value: impl Into<Box<PartitionStartRecord>>, ) -> Self
Initializes the enum to the PartitionStartRecord branch.
Sourcepub fn from_partition_end_record(
value: impl Into<Box<PartitionEndRecord>>,
) -> Self
pub fn from_partition_end_record( value: impl Into<Box<PartitionEndRecord>>, ) -> Self
Initializes the enum to the PartitionEndRecord branch.
Sourcepub fn from_partition_event_record(
value: impl Into<Box<PartitionEventRecord>>,
) -> Self
pub fn from_partition_event_record( value: impl Into<Box<PartitionEventRecord>>, ) -> Self
Initializes the enum to the PartitionEventRecord branch.