#[non_exhaustive]pub struct HeartbeatRecord {
pub timestamp: Option<Timestamp>,
/* private fields */
}Expand description
A heartbeat record is returned as a progress indicator, when there are no data changes or any other partition record types in the change stream partition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: Option<Timestamp>Indicates the timestamp at which the query has returned all the records in the change stream partition with timestamp <= heartbeat timestamp. The heartbeat timestamp will not be the same as the timestamps of other record types in the same partition.
Implementations