#[non_exhaustive]pub struct PartitionEndRecord {
pub end_timestamp: Option<Timestamp>,
pub record_sequence: String,
pub partition_token: String,
/* private fields */
}Expand description
A partition end record serves as a notification that the client should stop reading the partition. No further records are expected to be retrieved on it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.end_timestamp: Option<Timestamp>End timestamp at which the change stream partition is terminated. All changes generated by this partition will have timestamps <= end_timestamp. DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition. PartitionEndRecord is the last record returned for a partition.
record_sequence: StringRecord sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition.
partition_token: StringUnique partition identifier describing the terminated change stream partition. partition_token is equal to the partition token of the change stream partition currently queried to return this PartitionEndRecord.
Implementations
Sourceimpl PartitionEndRecord
impl PartitionEndRecord
Sourcepub fn set_end_timestamp<T>(self, v: T) -> Self
pub fn set_end_timestamp<T>(self, v: T) -> Self
Sets the value of end_timestamp.
Sourcepub fn set_or_clear_end_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of end_timestamp.
Sourcepub fn set_record_sequence<T: Into<String>>(self, v: T) -> Self
pub fn set_record_sequence<T: Into<String>>(self, v: T) -> Self
Sets the value of record_sequence.
Sourcepub fn set_partition_token<T: Into<String>>(self, v: T) -> Self
pub fn set_partition_token<T: Into<String>>(self, v: T) -> Self
Sets the value of partition_token.