PartitionEventRecord

Struct PartitionEventRecord 

#[non_exhaustive]
pub struct PartitionEventRecord { pub commit_timestamp: Option<Timestamp>, pub record_sequence: String, pub partition_token: String, pub move_in_events: Vec<MoveInEvent>, pub move_out_events: Vec<MoveOutEvent>, /* private fields */ }
A partition event record describes key range changes for a change stream partition. The changes to a row defined by its primary key can be captured in one change stream partition for a specific time range, and then be captured in a different change stream partition for a different time range. This movement of key ranges across change stream partitions is a reflection of activities, such as Spanner’s dynamic splitting and load balancing, etc. Processing this event is needed if users want to guarantee processing of the changes for any key in timestamp order. If time ordered processing of changes for a primary key is not needed, this event can be ignored. To guarantee time ordered processing for each primary key, if the event describes move-ins, the reader of this partition needs to wait until the readers of the source partitions have processed all records with timestamps <= this PartitionEventRecord.commit_timestamp, before advancing beyond this PartitionEventRecord. If the event describes move-outs, the reader can notify the readers of the destination partitions that they can continue processing.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
commit_timestamp: Option<Timestamp>

Indicates the commit timestamp at which the key range change occurred. DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition.

record_sequence: String

Record sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition.

partition_token: String

Unique partition identifier describing the partition this event occurred on. partition_token is equal to the partition token of the change stream partition currently queried to return this PartitionEventRecord.

move_in_events: Vec<MoveInEvent>

Set when one or more key ranges are moved into the change stream partition identified by partition_token.

Example: Two key ranges are moved into partition (P1) from partition (P2) and partition (P3) in a single transaction at timestamp T.

The PartitionEventRecord returned in P1 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P1” move_in_events { source_partition_token: “P2” } move_in_events { source_partition_token: “P3” } }

The PartitionEventRecord returned in P2 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P2” move_out_events { destination_partition_token: “P1” } }

The PartitionEventRecord returned in P3 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P3” move_out_events { destination_partition_token: “P1” } }

move_out_events: Vec<MoveOutEvent>

Set when one or more key ranges are moved out of the change stream partition identified by partition_token.

Example: Two key ranges are moved out of partition (P1) to partition (P2) and partition (P3) in a single transaction at timestamp T.

The PartitionEventRecord returned in P1 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P1” move_out_events { destination_partition_token: “P2” } move_out_events { destination_partition_token: “P3” } }

The PartitionEventRecord returned in P2 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P2” move_in_events { source_partition_token: “P1” } }

The PartitionEventRecord returned in P3 will reflect the move as:

PartitionEventRecord { commit_timestamp: T partition_token: “P3” move_in_events { source_partition_token: “P1” } }

Implementations

Source

impl PartitionEventRecord

pub fn new() -> Self

Creates a new default instance.

pub fn set_commit_timestamp<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of commit_timestamp.

pub fn set_or_clear_commit_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of commit_timestamp.

pub fn set_record_sequence<T: Into<String>>(self, v: T) -> Self

Sets the value of record_sequence.

pub fn set_partition_token<T: Into<String>>(self, v: T) -> Self

Sets the value of partition_token.

pub fn set_move_in_events<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<MoveInEvent>,

Sets the value of move_in_events.

pub fn set_move_out_events<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<MoveOutEvent>,

Sets the value of move_out_events.