#[non_exhaustive]pub struct PartitionStartRecord {
pub start_timestamp: Option<Timestamp>,
pub record_sequence: String,
pub partition_tokens: Vec<String>,
/* private fields */
}Expand description
A partition start record serves as a notification that the client should schedule the partitions to be queried. PartitionStartRecord returns information about one or more partitions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_timestamp: Option<Timestamp>Start timestamp at which the partitions should be queried to return change stream records with timestamps >= start_timestamp. DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition.
record_sequence: StringRecord sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition.
partition_tokens: Vec<String>Unique partition identifiers to be used in queries.
Implementations
Sourceimpl PartitionStartRecord
impl PartitionStartRecord
Sourcepub fn set_start_timestamp<T>(self, v: T) -> Self
pub fn set_start_timestamp<T>(self, v: T) -> Self
Sets the value of start_timestamp.
Sourcepub fn set_or_clear_start_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_timestamp.
Sourcepub fn set_record_sequence<T: Into<String>>(self, v: T) -> Self
pub fn set_record_sequence<T: Into<String>>(self, v: T) -> Self
Sets the value of record_sequence.
Sourcepub fn set_partition_tokens<T, V>(self, v: T) -> Self
pub fn set_partition_tokens<T, V>(self, v: T) -> Self
Sets the value of partition_tokens.