Transaction

Enum Transaction 

#[non_exhaustive]
pub enum Transaction { TransactionId(Bytes), SingleUseTransaction(Box<TransactionOptions>), }
Required. The transaction in which to commit.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TransactionId(Bytes)

Commit a previously-started transaction.



SingleUseTransaction(Box<TransactionOptions>)

Execute mutations in a temporary transaction. Note that unlike commit of a previously-started transaction, commit with a temporary transaction is non-idempotent. That is, if the CommitRequest is sent to Cloud Spanner more than once (for instance, due to retries in the application, or in the transport library), it’s possible that the mutations are executed more than once. If this is undesirable, use BeginTransaction and Commit instead.

Implementations

Source

impl Transaction

pub fn from_transaction_id(value: impl Into<Bytes>) -> Self

Initializes the enum to the TransactionId branch.

pub fn from_single_use_transaction( value: impl Into<Box<TransactionOptions>>, ) -> Self

Initializes the enum to the SingleUseTransaction branch.