#[non_exhaustive]pub enum MultiplexedSessionRetry {
PrecommitToken(Box<MultiplexedSessionPrecommitToken>),
}Expand description
You must examine and retry the commit if the following is populated.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PrecommitToken(Box<MultiplexedSessionPrecommitToken>)
If specified, transaction has not committed yet. You must retry the commit with the new precommit token.
Implementations
Sourceimpl MultiplexedSessionRetry
impl MultiplexedSessionRetry
Sourcepub fn from_precommit_token(
value: impl Into<Box<MultiplexedSessionPrecommitToken>>,
) -> Self
pub fn from_precommit_token( value: impl Into<Box<MultiplexedSessionPrecommitToken>>, ) -> Self
Initializes the enum to the PrecommitToken branch.