CommitStats

Struct CommitStats 

#[non_exhaustive]
pub struct CommitStats { pub mutation_count: i64, /* private fields */ }
Additional statistics about a commit.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mutation_count: i64

The total number of mutations for the transaction. Knowing the mutation_count value can help you maximize the number of mutations in a transaction and minimize the number of API round trips. You can also monitor this value to prevent transactions from exceeding the system limit. If the number of mutations exceeds the limit, the server returns INVALID_ARGUMENT.

Implementations

Source

impl CommitStats

pub fn new() -> Self

Creates a new default instance.

pub fn set_mutation_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of mutation_count.