Module directed_read_options

Module directed_read_options 

Defines additional types related to DirectedReadOptions.

Modules

replica_selection
Defines additional types related to ReplicaSelection.

Structs

ExcludeReplicas
An ExcludeReplicas contains a repeated set of ReplicaSelection that should be excluded from serving requests.
IncludeReplicas
An IncludeReplicas contains a repeated set of ReplicaSelection which indicates the order in which replicas should be considered.
ReplicaSelection
The directed read replica selector. Callers must provide one or more of the following fields for replica selection:

Enums

Replicas
Required. At most one of either include_replicas or exclude_replicas should be present in the message.