#[non_exhaustive]pub enum Replicas {
IncludeReplicas(Box<IncludeReplicas>),
ExcludeReplicas(Box<ExcludeReplicas>),
}Expand description
Required. At most one of either include_replicas or exclude_replicas
should be present in the message.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncludeReplicas(Box<IncludeReplicas>)
Include_replicas indicates the order of replicas (as they appear in
this list) to process the request. If auto_failover_disabled is set to
true and all replicas are exhausted without finding a healthy replica,
Spanner waits for a replica in the list to become available, requests
might fail due to DEADLINE_EXCEEDED errors.
ExcludeReplicas(Box<ExcludeReplicas>)
Exclude_replicas indicates that specified replicas should be excluded
from serving requests. Spanner doesn’t route requests to the replicas
in this list.
Implementations
Sourceimpl Replicas
impl Replicas
Sourcepub fn from_include_replicas(value: impl Into<Box<IncludeReplicas>>) -> Self
pub fn from_include_replicas(value: impl Into<Box<IncludeReplicas>>) -> Self
Initializes the enum to the IncludeReplicas branch.
Sourcepub fn from_exclude_replicas(value: impl Into<Box<ExcludeReplicas>>) -> Self
pub fn from_exclude_replicas(value: impl Into<Box<ExcludeReplicas>>) -> Self
Initializes the enum to the ExcludeReplicas branch.