#[non_exhaustive]pub struct IncludeReplicas {
pub replica_selections: Vec<ReplicaSelection>,
pub auto_failover_disabled: bool,
/* private fields */
}Expand description
An IncludeReplicas contains a repeated set of ReplicaSelection which
indicates the order in which replicas should be considered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replica_selections: Vec<ReplicaSelection>The directed read replica selector.
auto_failover_disabled: boolIf true, Spanner doesn’t route requests to a replica outside the
<include_replicas list when all of the specified replicas are
unavailable or unhealthy. Default value is false.
Implementations
Sourceimpl IncludeReplicas
impl IncludeReplicas
Sourcepub fn set_replica_selections<T, V>(self, v: T) -> Self
pub fn set_replica_selections<T, V>(self, v: T) -> Self
Sets the value of replica_selections.
Sourcepub fn set_auto_failover_disabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_auto_failover_disabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of auto_failover_disabled.