#[non_exhaustive]pub struct ReplicaSelection {
pub location: String,
pub type: Type,
/* private fields */
}Expand description
The directed read replica selector. Callers must provide one or more of the following fields for replica selection:
location- The location must be one of the regions within the multi-region configuration of your database.type- The type of the replica.
Some examples of using replica_selectors are:
location:us-east1–> The “us-east1” replica(s) of any available type is used to process the request.type:READ_ONLY–> The “READ_ONLY” type replica(s) in the nearest available location are used to process the request.location:us-east1 type:READ_ONLY–> The “READ_ONLY” type replica(s) in location “us-east1” is used to process the request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: StringThe location or region of the serving requests, for example, “us-east1”.
type: TypeThe type of replica.
Implementations