Statement

#[non_exhaustive]
pub struct Statement { pub sql: String, pub params: Option<Struct>, pub param_types: HashMap<String, Type>, /* private fields */ }
A single DML statement.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
sql: String

Required. The DML string.

params: Option<Struct>

Parameter names and values that bind to placeholders in the DML string.

A parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName). Parameter names can contain letters, numbers, and underscores.

Parameters can appear anywhere that a literal value is expected. The same parameter name can be used more than once, for example:

"WHERE id > @msg_id AND id < @msg_id + 100"

It’s an error to execute a SQL statement with unbound parameters.

param_types: HashMap<String, Type>

It isn’t always possible for Cloud Spanner to infer the right SQL type from a JSON value. For example, values of type BYTES and values of type STRING both appear in params as JSON strings.

In these cases, param_types can be used to specify the exact SQL type for some or all of the SQL statement parameters. See the definition of Type for more information about SQL types.

Implementations

Source

impl Statement

pub fn new() -> Self

Creates a new default instance.

pub fn set_sql<T: Into<String>>(self, v: T) -> Self

Sets the value of sql.

pub fn set_params<T>(self, v: T) -> Self
where T: Into<Struct>,

Sets the value of params.

pub fn set_or_clear_params<T>(self, v: Option<T>) -> Self
where T: Into<Struct>,

Sets or clears the value of params.

pub fn set_param_types<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<Type>,

Sets the value of param_types.