#[non_exhaustive]pub enum QueryMode {
Normal,
Plan,
Profile,
WithStats,
WithPlanAndStats,
UnknownValue(UnknownValue),
}Expand description
Mode in which the statement must be processed.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Normal
The default mode. Only the statement results are returned.
Plan
This mode returns only the query plan, without any results or execution statistics information.
Profile
This mode returns the query plan, overall execution statistics, operator level execution statistics along with the results. This has a performance overhead compared to the other modes. It isn’t recommended to use this mode for production traffic.
WithStats
This mode returns the overall (but not operator-level) execution statistics along with the results.
WithPlanAndStats
This mode returns the query plan, overall (but not operator-level) execution statistics along with the results.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using QueryMode::value or QueryMode::name.
Implementations