#[non_exhaustive]pub enum Target {
TableName(String),
IndexName(String),
OperationUid(u64),
}Expand description
A recipe can be associated with a table, index, or query. Tables recipes are used to encode read and write keys; index recipes are used for index reads, and query recipes are used only for SQL queries.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TableName(String)
A table name, matching the name from the database schema.
IndexName(String)
An index name, matching the name from the database schema.
OperationUid(u64)
The UID of a query, matching the UID from RoutingHint.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn from_table_name(value: impl Into<String>) -> Self
pub fn from_table_name(value: impl Into<String>) -> Self
Initializes the enum to the TableName branch.
Sourcepub fn from_index_name(value: impl Into<String>) -> Self
pub fn from_index_name(value: impl Into<String>) -> Self
Initializes the enum to the IndexName branch.
Sourcepub fn from_operation_uid(value: impl Into<u64>) -> Self
pub fn from_operation_uid(value: impl Into<u64>) -> Self
Initializes the enum to the OperationUid branch.