#[non_exhaustive]pub enum NullOrder {
Unspecified,
NullsFirst,
NullsLast,
NotNull,
UnknownValue(UnknownValue),
}Expand description
The null order of the key column. This dictates where NULL values sort
in the sorted order. Note that columns which are NOT NULL can have a
special encoding.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. This value is unused.
NullsFirst
NULL values sort before any non-NULL values.
NullsLast
NULL values sort after any non-NULL values.
NotNull
The column does not support NULL values.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NullOrder::value or NullOrder::name.
Implementations