Part

Struct Part 

#[non_exhaustive]
pub struct Part { pub tag: u32, pub order: Order, pub null_order: NullOrder, pub type: Option<Type>, pub struct_identifiers: Vec<i32>, pub value_type: Option<ValueType>, /* private fields */ }
An ssformat key is composed of a sequence of tag numbers and key column values. Part represents a single tag or key column value.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tag: u32

If non-zero, tag is the only field present in this Part. The part is encoded by appending tag to the ssformat key.

order: Order

Whether the key column is sorted ascending or descending. Only present if tag is zero.

null_order: NullOrder

How NULLs are represented in the encoded key part. Only present if tag is zero.

type: Option<Type>

The type of the key part. Only present if tag is zero.

struct_identifiers: Vec<i32>

It is a repeated field to support fetching key columns from nested structs, such as STRUCT query parameters.

value_type: Option<ValueType>

Only present if tag is zero.

Implementations

Source

impl Part

pub fn new() -> Self

Creates a new default instance.

pub fn set_tag<T: Into<u32>>(self, v: T) -> Self

Sets the value of tag.

pub fn set_order<T: Into<Order>>(self, v: T) -> Self

Sets the value of order.

pub fn set_null_order<T: Into<NullOrder>>(self, v: T) -> Self

Sets the value of null_order.

pub fn set_type<T>(self, v: T) -> Self
where T: Into<Type>,

Sets the value of r#type.

pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
where T: Into<Type>,

Sets or clears the value of r#type.

pub fn set_struct_identifiers<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<i32>,

Sets the value of struct_identifiers.

pub fn set_value_type<T: Into<Option<ValueType>>>(self, v: T) -> Self

Sets the value of value_type.

Note that all the setters affecting value_type are mutually exclusive.

pub fn identifier(&self) -> Option<&String>

The value of value_type if it holds a Identifier, None if the field is not set or holds a different branch.

pub fn set_identifier<T: Into<String>>(self, v: T) -> Self

Sets the value of value_type to hold a Identifier.

Note that all the setters affecting value_type are mutually exclusive.

pub fn value(&self) -> Option<&Box<Value>>

The value of value_type if it holds a Value, None if the field is not set or holds a different branch.

pub fn set_value<T: Into<Box<Value>>>(self, v: T) -> Self

Sets the value of value_type to hold a Value.

Note that all the setters affecting value_type are mutually exclusive.

pub fn random(&self) -> Option<&bool>

The value of value_type if it holds a Random, None if the field is not set or holds a different branch.

pub fn set_random<T: Into<bool>>(self, v: T) -> Self

Sets the value of value_type to hold a Random.

Note that all the setters affecting value_type are mutually exclusive.