Operation

Enum Operation 

#[non_exhaustive]
pub enum Operation { Insert(Box<Write>), Update(Box<Write>), InsertOrUpdate(Box<Write>), Replace(Box<Write>), Delete(Box<Delete>), Send(Box<Send>), Ack(Box<Ack>), }
Required. The operation to perform.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Insert(Box<Write>)

Insert new rows in a table. If any of the rows already exist, the write or transaction fails with error ALREADY_EXISTS.



Update(Box<Write>)

Update existing rows in a table. If any of the rows does not already exist, the transaction fails with error NOT_FOUND.



InsertOrUpdate(Box<Write>)

Like insert, except that if the row already exists, then its column values are overwritten with the ones provided. Any column values not explicitly written are preserved.

When using insert_or_update, just as when using insert, all NOT NULL columns in the table must be given a value. This holds true even when the row already exists and will therefore actually be updated.



Replace(Box<Write>)

Like insert, except that if the row already exists, it is deleted, and the column values provided are inserted instead. Unlike insert_or_update, this means any values not explicitly written become NULL.

In an interleaved table, if you create the child table with the ON DELETE CASCADE annotation, then replacing a parent row also deletes the child rows. Otherwise, you must delete the child rows before you replace the parent row.



Delete(Box<Delete>)

Delete rows from a table. Succeeds whether or not the named rows were present.



Send(Box<Send>)

Send a message to a queue.



Ack(Box<Ack>)

Ack a message from a queue.

Implementations

Source

impl Operation

pub fn from_insert(value: impl Into<Box<Write>>) -> Self

Initializes the enum to the Insert branch.

pub fn from_update(value: impl Into<Box<Write>>) -> Self

Initializes the enum to the Update branch.

pub fn from_insert_or_update(value: impl Into<Box<Write>>) -> Self

Initializes the enum to the InsertOrUpdate branch.

pub fn from_replace(value: impl Into<Box<Write>>) -> Self

Initializes the enum to the Replace branch.

pub fn from_delete(value: impl Into<Box<Delete>>) -> Self

Initializes the enum to the Delete branch.

pub fn from_send(value: impl Into<Box<Send>>) -> Self

Initializes the enum to the Send branch.

pub fn from_ack(value: impl Into<Box<Ack>>) -> Self

Initializes the enum to the Ack branch.