#[non_exhaustive]pub struct Ack {
pub queue: String,
pub key: Option<ListValue>,
pub ignore_not_found: bool,
/* private fields */
}Expand description
Arguments to ack operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.queue: StringRequired. The queue where the message to be acked is stored.
key: Option<ListValue>Required. The primary key of the message to be acked.
ignore_not_found: boolBy default, an attempt to ack a message that does not exist will fail
with a NOT_FOUND error. With ignore_not_found set to true, the ack
will succeed even if the message does not exist. This is useful for
unconditionally acking a message, even if it is missing or has already
been acked.
Implementations
Sourceimpl Ack
impl Ack
Sourcepub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
Sets or clears the value of key.
Sourcepub fn set_ignore_not_found<T: Into<bool>>(self, v: T) -> Self
pub fn set_ignore_not_found<T: Into<bool>>(self, v: T) -> Self
Sets the value of ignore_not_found.