#[non_exhaustive]pub struct Send {
pub queue: String,
pub key: Option<ListValue>,
pub deliver_time: Option<Timestamp>,
pub payload: Option<Value>,
/* private fields */
}Expand description
Arguments to send operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.queue: StringRequired. The queue to which the message will be sent.
key: Option<ListValue>Required. The primary key of the message to be sent.
deliver_time: Option<Timestamp>The time at which Spanner will begin attempting to deliver the message.
If deliver_time is not set, Spanner will deliver the message
immediately. If deliver_time is in the past, Spanner will replace it
with a value closer to the current time.
payload: Option<Value>The payload of the message.
Implementations
Sourceimpl Send
impl Send
Sourcepub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
Sets or clears the value of key.
Sourcepub fn set_deliver_time<T>(self, v: T) -> Self
pub fn set_deliver_time<T>(self, v: T) -> Self
Sets the value of deliver_time.
Sourcepub fn set_or_clear_deliver_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deliver_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of deliver_time.
Sourcepub fn set_payload<T>(self, v: T) -> Self
pub fn set_payload<T>(self, v: T) -> Self
Sets the value of payload.