#[non_exhaustive]pub struct Write {
pub table: String,
pub columns: Vec<String>,
pub values: Vec<ListValue>,
/* private fields */
}Expand description
Arguments to insert, update, insert_or_update, and replace operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table: StringRequired. The table whose rows will be written.
columns: Vec<String>The names of the columns in table to be written.
The list of columns must contain enough columns to allow Cloud Spanner to derive values for all primary key columns in the row(s) to be modified.
values: Vec<ListValue>The values to be written. values can contain more than one
list of values. If it does, then multiple rows are written, one
for each entry in values. Each list in values must have
exactly as many entries as there are entries in
columns above. Sending
multiple lists is equivalent to sending multiple Mutations, each
containing one values entry and repeating
table and
columns. Individual values in
each list are encoded as described here.
Implementations
Sourceimpl Write
impl Write
Sourcepub fn set_columns<T, V>(self, v: T) -> Self
pub fn set_columns<T, V>(self, v: T) -> Self
Sets the value of columns.
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self
Sets the value of values.