#[non_exhaustive]pub enum Kind {
Unspecified,
Relational,
Scalar,
UnknownValue(UnknownValue),
}Expand description
The kind of PlanNode. Distinguishes between the two different kinds of nodes that can appear in a query plan.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not specified.
Relational
Denotes a Relational operator node in the expression tree. Relational
operators represent iterative processing of rows during query execution.
For example, a TableScan operation that reads rows from a table.
Scalar
Denotes a Scalar node in the expression tree. Scalar nodes represent non-iterable entities in the query plan. For example, constants or arithmetic operators appearing inside predicate expressions or references to column names.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Kind::value or Kind::name.
Implementations