#[non_exhaustive]pub struct ChildLink {
pub child_index: i32,
pub type: String,
pub variable: String,
/* private fields */
}Expand description
Metadata associated with a parent-child relationship appearing in a PlanNode.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.child_index: i32The node to which the link points.
type: StringThe type of the link. For example, in Hash Joins this could be used to distinguish between the build child and the probe child, or in the case of the child being an output variable, to represent the tag associated with the output variable.
variable: StringOnly present if the child node is
SCALAR and corresponds to an
output variable of the parent node. The field carries the name of the
output variable. For example, a TableScan operator that reads rows from
a table will have child links to the SCALAR nodes representing the
output variables created for each column that is read by the operator.
The corresponding variable fields will be set to the variable names
assigned to the columns.
Implementations
Sourceimpl ChildLink
impl ChildLink
Sourcepub fn set_child_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_child_index<T: Into<i32>>(self, v: T) -> Self
Sets the value of child_index.
Sourcepub fn set_variable<T: Into<String>>(self, v: T) -> Self
pub fn set_variable<T: Into<String>>(self, v: T) -> Self
Sets the value of variable.