#[non_exhaustive]pub struct ShortRepresentation {
pub description: String,
pub subqueries: HashMap<String, i32>,
/* private fields */
}Expand description
Condensed representation of a node and its subtree. Only present for
SCALAR PlanNode(s).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: StringA string representation of the expression subtree rooted at this node.
subqueries: HashMap<String, i32>A mapping of (subquery variable name) -> (subquery node id) for cases
where the description string of this node references a SCALAR
subquery contained in the expression subtree rooted at this node. The
referenced SCALAR subquery may not necessarily be a direct child of
this node.
Implementations
Sourceimpl ShortRepresentation
impl ShortRepresentation
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Sourcepub fn set_subqueries<T, K, V>(self, v: T) -> Self
pub fn set_subqueries<T, K, V>(self, v: T) -> Self
Sets the value of subqueries.