#[non_exhaustive]pub struct IndexAdvice {
pub ddl: Vec<String>,
pub improvement_factor: f64,
/* private fields */
}Expand description
Recommendation to add new indexes to run queries more efficiently.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ddl: Vec<String>Optional. DDL statements to add new indexes that will improve the query.
improvement_factor: f64Optional. Estimated latency improvement factor. For example if the query currently takes 500 ms to run and the estimated latency with new indexes is 100 ms this field will be 5.
Implementations
Sourceimpl IndexAdvice
impl IndexAdvice
Sourcepub fn set_improvement_factor<T: Into<f64>>(self, v: T) -> Self
pub fn set_improvement_factor<T: Into<f64>>(self, v: T) -> Self
Sets the value of improvement_factor.