Module read_request

Module read_request 

Defines additional types related to ReadRequest.

Enums

LockHint
A lock hint mechanism for reads done within a transaction.
OrderBy
An option to control the order in which rows are returned from a read.