#[non_exhaustive]pub enum OrderBy {
Unspecified,
PrimaryKey,
NoOrder,
UnknownValue(UnknownValue),
}Expand description
An option to control the order in which rows are returned from a read.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
ORDER_BY_UNSPECIFIED is equivalent to ORDER_BY_PRIMARY_KEY.
PrimaryKey
Read rows are returned in primary key order.
In the event that this option is used in conjunction with the
partition_token field, the API returns an INVALID_ARGUMENT error.
NoOrder
Read rows are returned in any order.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using OrderBy::value or OrderBy::name.
Implementations