#[non_exhaustive]pub enum Priority {
Unspecified,
Low,
Medium,
High,
UnknownValue(UnknownValue),
}Expand description
The relative priority for requests. Note that priority isn’t applicable for BeginTransaction.
The priority acts as a hint to the Cloud Spanner scheduler and doesn’t guarantee priority or order of execution. For example:
- Some parts of a write operation always execute at
PRIORITY_HIGH, regardless of the specified priority. This can cause you to see an increase in high priority workload even when executing a low priority request. This can also potentially cause a priority inversion where a lower priority request is fulfilled ahead of a higher priority request. - If a transaction contains multiple operations with different priorities, Cloud Spanner doesn’t guarantee to process the higher priority operations first. There might be other constraints to satisfy, such as the order of operations.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
PRIORITY_UNSPECIFIED is equivalent to PRIORITY_HIGH.
Low
This specifies that the request is low priority.
Medium
This specifies that the request is medium priority.
High
This specifies that the request is high priority.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Priority::value or Priority::name.
Implementations