#[non_exhaustive]pub enum RowCount {
RowCountExact(i64),
RowCountLowerBound(i64),
}Expand description
The number of rows modified by the DML statement.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RowCountExact(i64)
Standard DML returns an exact count of rows that were modified.
RowCountLowerBound(i64)
Partitioned DML doesn’t offer exactly-once semantics, so it returns a lower bound of the rows modified.
Implementations
Sourceimpl RowCount
impl RowCount
Sourcepub fn from_row_count_exact(value: impl Into<i64>) -> Self
pub fn from_row_count_exact(value: impl Into<i64>) -> Self
Initializes the enum to the RowCountExact branch.
Sourcepub fn from_row_count_lower_bound(value: impl Into<i64>) -> Self
pub fn from_row_count_lower_bound(value: impl Into<i64>) -> Self
Initializes the enum to the RowCountLowerBound branch.