BatchCreateSessionsRequest

Struct BatchCreateSessionsRequest 

#[non_exhaustive]
pub struct BatchCreateSessionsRequest { pub database: String, pub session_template: Option<Session>, pub session_count: i32, /* private fields */ }
The request for BatchCreateSessions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
database: String

Required. The database in which the new sessions are created.

session_template: Option<Session>

Parameters to apply to each created session.

session_count: i32

Required. The number of sessions to be created in this batch call. At least one session is created. The API can return fewer than the requested number of sessions. If a specific number of sessions are desired, the client can make additional calls to BatchCreateSessions (adjusting session_count as necessary).

Implementations

Source

impl BatchCreateSessionsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_database<T: Into<String>>(self, v: T) -> Self

Sets the value of database.

pub fn set_session_template<T>(self, v: T) -> Self
where T: Into<Session>,

Sets the value of session_template.

pub fn set_or_clear_session_template<T>(self, v: Option<T>) -> Self
where T: Into<Session>,

Sets or clears the value of session_template.

pub fn set_session_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of session_count.