BatchWriteRequest

Struct BatchWriteRequest 

#[non_exhaustive]
pub struct BatchWriteRequest { pub session: String, pub request_options: Option<RequestOptions>, pub mutation_groups: Vec<MutationGroup>, pub exclude_txn_from_change_streams: bool, /* private fields */ }
The request for [BatchWrite][google.spanner.v1.Spanner.BatchWrite].

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session in which the batch request is to be run.

request_options: Option<RequestOptions>

Common options for this request.

mutation_groups: Vec<MutationGroup>

Required. The groups of mutations to be applied.

exclude_txn_from_change_streams: bool

Optional. If you don’t set the exclude_txn_from_change_streams option or if it’s set to false, then any change streams monitoring columns modified by transactions will capture the updates made within that transaction.

Implementations

Source

impl BatchWriteRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_request_options<T>(self, v: T) -> Self
where T: Into<RequestOptions>,

Sets the value of request_options.

pub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Self
where T: Into<RequestOptions>,

Sets or clears the value of request_options.

pub fn set_mutation_groups<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<MutationGroup>,

Sets the value of mutation_groups.

pub fn set_exclude_txn_from_change_streams<T: Into<bool>>(self, v: T) -> Self