#[non_exhaustive]pub struct BatchWriteResponse {
pub indexes: Vec<i32>,
pub status: Option<Status>,
pub commit_timestamp: Option<Timestamp>,
/* private fields */
}Expand description
The result of applying a batch of mutations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.indexes: Vec<i32>The mutation groups applied in this batch. The values index into the
mutation_groups field in the corresponding BatchWriteRequest.
status: Option<Status>An OK status indicates success. Any other status indicates a failure.
commit_timestamp: Option<Timestamp>The commit timestamp of the transaction that applied this batch. Present if status is OK and the mutation groups were applied, absent otherwise.
For mutation groups with conditions, a status=OK and missing commit_timestamp means that the mutation groups were not applied due to the condition not being satisfied after evaluation.
Implementations
Sourceimpl BatchWriteResponse
impl BatchWriteResponse
Sourcepub fn set_indexes<T, V>(self, v: T) -> Self
pub fn set_indexes<T, V>(self, v: T) -> Self
Sets the value of indexes.
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Sourcepub fn set_commit_timestamp<T>(self, v: T) -> Self
pub fn set_commit_timestamp<T>(self, v: T) -> Self
Sets the value of commit_timestamp.
Sourcepub fn set_or_clear_commit_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_commit_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of commit_timestamp.