BeginTransactionRequest

Struct BeginTransactionRequest 

#[non_exhaustive]
pub struct BeginTransactionRequest { pub session: String, pub options: Option<TransactionOptions>, pub request_options: Option<RequestOptions>, pub mutation_key: Option<Mutation>, pub routing_hint: Option<RoutingHint>, /* private fields */ }
The request for BeginTransaction.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session in which the transaction runs.

options: Option<TransactionOptions>

Required. Options for the new transaction.

request_options: Option<RequestOptions>

Common options for this request. Priority is ignored for this request. Setting the priority in this request_options struct doesn’t do anything. To set the priority for a transaction, set it on the reads and writes that are part of this transaction instead.

mutation_key: Option<Mutation>

Optional. Required for read-write transactions on a multiplexed session that commit mutations but don’t perform any reads or queries. You must randomly select one of the mutations from the mutation set and send it as a part of this request.

routing_hint: Option<RoutingHint>

Optional. Makes the Spanner requests location-aware if present.

It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.

Implementations

Source

impl BeginTransactionRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_options<T>(self, v: T) -> Self

Sets the value of options.

pub fn set_or_clear_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of options.

pub fn set_request_options<T>(self, v: T) -> Self
where T: Into<RequestOptions>,

Sets the value of request_options.

pub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Self
where T: Into<RequestOptions>,

Sets or clears the value of request_options.

pub fn set_mutation_key<T>(self, v: T) -> Self
where T: Into<Mutation>,

Sets the value of mutation_key.

pub fn set_or_clear_mutation_key<T>(self, v: Option<T>) -> Self
where T: Into<Mutation>,

Sets or clears the value of mutation_key.

pub fn set_routing_hint<T>(self, v: T) -> Self
where T: Into<RoutingHint>,

Sets the value of routing_hint.

pub fn set_or_clear_routing_hint<T>(self, v: Option<T>) -> Self
where T: Into<RoutingHint>,

Sets or clears the value of routing_hint.