CacheUpdate

Struct CacheUpdate 

#[non_exhaustive]
pub struct CacheUpdate { pub database_id: u64, pub range: Vec<Range>, pub group: Vec<Group>, pub key_recipes: Option<RecipeList>, /* private fields */ }
A CacheUpdate expresses a set of changes the client should incorporate into its location cache. These changes may or may not be newer than what the client has in its cache, and should be discarded if necessary. CacheUpdates can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
database_id: u64

An internal ID for the database. Database names can be reused if a database is deleted and re-created. Each time the database is re-created, it will get a new database ID, which will never be re-used for any other database.

range: Vec<Range>

A list of ranges to be cached.

group: Vec<Group>

A list of groups to be cached.

key_recipes: Option<RecipeList>

A list of recipes to be cached.

Implementations

Source

impl CacheUpdate

pub fn new() -> Self

Creates a new default instance.

pub fn set_database_id<T: Into<u64>>(self, v: T) -> Self

Sets the value of database_id.

pub fn set_range<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Range>,

Sets the value of range.

pub fn set_group<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Group>,

Sets the value of group.

pub fn set_key_recipes<T>(self, v: T) -> Self
where T: Into<RecipeList>,

Sets the value of key_recipes.

pub fn set_or_clear_key_recipes<T>(self, v: Option<T>) -> Self
where T: Into<RecipeList>,

Sets or clears the value of key_recipes.