CommitRequest

Struct CommitRequest 

#[non_exhaustive]
pub struct CommitRequest { pub session: String, pub mutations: Vec<Mutation>, pub return_commit_stats: bool, pub max_commit_delay: Option<Duration>, pub request_options: Option<RequestOptions>, pub precommit_token: Option<MultiplexedSessionPrecommitToken>, pub routing_hint: Option<RoutingHint>, pub transaction: Option<Transaction>, /* private fields */ }
The request for Commit.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session in which the transaction to be committed is running.

mutations: Vec<Mutation>

The mutations to be executed when this transaction commits. All mutations are applied atomically, in the order they appear in this list.

return_commit_stats: bool

If true, then statistics related to the transaction is included in the CommitResponse. Default value is false.

max_commit_delay: Option<Duration>

Optional. The amount of latency this request is configured to incur in order to improve throughput. If this field isn’t set, Spanner assumes requests are relatively latency sensitive and automatically determines an appropriate delay time. You can specify a commit delay value between 0 and 500 ms.

request_options: Option<RequestOptions>

Common options for this request.

precommit_token: Option<MultiplexedSessionPrecommitToken>

Optional. If the read-write transaction was executed on a multiplexed session, then you must include the precommit token with the highest sequence number received in this transaction attempt. Failing to do so results in a FailedPrecondition error.

routing_hint: Option<RoutingHint>

Optional. Makes the Spanner requests location-aware if present.

It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.

transaction: Option<Transaction>

Required. The transaction in which to commit.

Implementations

Source

impl CommitRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_mutations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Mutation>,

Sets the value of mutations.

pub fn set_return_commit_stats<T: Into<bool>>(self, v: T) -> Self

Sets the value of return_commit_stats.

pub fn set_max_commit_delay<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of max_commit_delay.

pub fn set_or_clear_max_commit_delay<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of max_commit_delay.

pub fn set_request_options<T>(self, v: T) -> Self
where T: Into<RequestOptions>,

Sets the value of request_options.

pub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Self
where T: Into<RequestOptions>,

Sets or clears the value of request_options.

pub fn set_precommit_token<T>(self, v: T) -> Self

Sets the value of precommit_token.

pub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Self

Sets or clears the value of precommit_token.

pub fn set_routing_hint<T>(self, v: T) -> Self
where T: Into<RoutingHint>,

Sets the value of routing_hint.

pub fn set_or_clear_routing_hint<T>(self, v: Option<T>) -> Self
where T: Into<RoutingHint>,

Sets or clears the value of routing_hint.

pub fn set_transaction<T: Into<Option<Transaction>>>(self, v: T) -> Self

Sets the value of transaction.

Note that all the setters affecting transaction are mutually exclusive.

pub fn transaction_id(&self) -> Option<&Bytes>

The value of transaction if it holds a TransactionId, None if the field is not set or holds a different branch.

pub fn set_transaction_id<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of transaction to hold a TransactionId.

Note that all the setters affecting transaction are mutually exclusive.

pub fn single_use_transaction(&self) -> Option<&Box<TransactionOptions>>

The value of transaction if it holds a SingleUseTransaction, None if the field is not set or holds a different branch.

pub fn set_single_use_transaction<T: Into<Box<TransactionOptions>>>( self, v: T, ) -> Self

Sets the value of transaction to hold a SingleUseTransaction.

Note that all the setters affecting transaction are mutually exclusive.