CommitResponse

Struct CommitResponse 

#[non_exhaustive]
pub struct CommitResponse { pub commit_timestamp: Option<Timestamp>, pub commit_stats: Option<CommitStats>, pub snapshot_timestamp: Option<Timestamp>, pub cache_update: Option<CacheUpdate>, pub isolation_level: IsolationLevel, pub read_lock_mode: ReadLockMode, pub multiplexed_session_retry: Option<MultiplexedSessionRetry>, /* private fields */ }
The response for Commit.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
commit_timestamp: Option<Timestamp>

The Cloud Spanner timestamp at which the transaction committed.

commit_stats: Option<CommitStats>

The statistics about this Commit. Not returned by default. For more information, see CommitRequest.return_commit_stats.

snapshot_timestamp: Option<Timestamp>

If TransactionOptions.isolation_level is set to IsolationLevel.REPEATABLE_READ, then the snapshot timestamp is the timestamp at which all reads in the transaction ran. This timestamp is never returned.

cache_update: Option<CacheUpdate>

Optional. A cache update expresses a set of changes the client should incorporate into its location cache. The client should discard the changes if they are older than the data it already has. This data can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.

isolation_level: IsolationLevel

The isolation level used for the read-write transaction.

read_lock_mode: ReadLockMode

The read lock mode used for the read-write transaction.

multiplexed_session_retry: Option<MultiplexedSessionRetry>

You must examine and retry the commit if the following is populated.

Implementations

Source

impl CommitResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_commit_timestamp<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of commit_timestamp.

pub fn set_or_clear_commit_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of commit_timestamp.

pub fn set_commit_stats<T>(self, v: T) -> Self
where T: Into<CommitStats>,

Sets the value of commit_stats.

pub fn set_or_clear_commit_stats<T>(self, v: Option<T>) -> Self
where T: Into<CommitStats>,

Sets or clears the value of commit_stats.

pub fn set_snapshot_timestamp<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of snapshot_timestamp.

pub fn set_or_clear_snapshot_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of snapshot_timestamp.

pub fn set_cache_update<T>(self, v: T) -> Self
where T: Into<CacheUpdate>,

Sets the value of cache_update.

pub fn set_or_clear_cache_update<T>(self, v: Option<T>) -> Self
where T: Into<CacheUpdate>,

Sets or clears the value of cache_update.

pub fn set_isolation_level<T: Into<IsolationLevel>>(self, v: T) -> Self

Sets the value of isolation_level.

pub fn set_read_lock_mode<T: Into<ReadLockMode>>(self, v: T) -> Self

Sets the value of read_lock_mode.

pub fn set_multiplexed_session_retry<T: Into<Option<MultiplexedSessionRetry>>>( self, v: T, ) -> Self

Sets the value of multiplexed_session_retry.

Note that all the setters affecting multiplexed_session_retry are mutually exclusive.

pub fn precommit_token(&self) -> Option<&Box<MultiplexedSessionPrecommitToken>>

The value of multiplexed_session_retry if it holds a PrecommitToken, None if the field is not set or holds a different branch.

pub fn set_precommit_token<T: Into<Box<MultiplexedSessionPrecommitToken>>>( self, v: T, ) -> Self

Sets the value of multiplexed_session_retry to hold a PrecommitToken.

Note that all the setters affecting multiplexed_session_retry are mutually exclusive.