#[non_exhaustive]pub struct DirectedReadOptions {
pub replicas: Option<Replicas>,
/* private fields */
}Expand description
The DirectedReadOptions can be used to indicate which replicas or regions
should be used for non-transactional reads or queries.
DirectedReadOptions can only be specified for a read-only transaction,
otherwise the API returns an INVALID_ARGUMENT error.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replicas: Option<Replicas>Required. At most one of either include_replicas or exclude_replicas
should be present in the message.
Implementations
Sourceimpl DirectedReadOptions
impl DirectedReadOptions
Sourcepub fn set_replicas<T: Into<Option<Replicas>>>(self, v: T) -> Self
pub fn set_replicas<T: Into<Option<Replicas>>>(self, v: T) -> Self
Sets the value of replicas.
Note that all the setters affecting replicas are mutually
exclusive.
Sourcepub fn include_replicas(&self) -> Option<&Box<IncludeReplicas>>
pub fn include_replicas(&self) -> Option<&Box<IncludeReplicas>>
The value of replicas
if it holds a IncludeReplicas, None if the field is not set or
holds a different branch.
Sourcepub fn set_include_replicas<T: Into<Box<IncludeReplicas>>>(self, v: T) -> Self
pub fn set_include_replicas<T: Into<Box<IncludeReplicas>>>(self, v: T) -> Self
Sets the value of replicas
to hold a IncludeReplicas.
Note that all the setters affecting replicas are
mutually exclusive.
Sourcepub fn exclude_replicas(&self) -> Option<&Box<ExcludeReplicas>>
pub fn exclude_replicas(&self) -> Option<&Box<ExcludeReplicas>>
The value of replicas
if it holds a ExcludeReplicas, None if the field is not set or
holds a different branch.
Sourcepub fn set_exclude_replicas<T: Into<Box<ExcludeReplicas>>>(self, v: T) -> Self
pub fn set_exclude_replicas<T: Into<Box<ExcludeReplicas>>>(self, v: T) -> Self
Sets the value of replicas
to hold a ExcludeReplicas.
Note that all the setters affecting replicas are
mutually exclusive.