ExecuteBatchDmlResponse

Struct ExecuteBatchDmlResponse 

#[non_exhaustive]
pub struct ExecuteBatchDmlResponse { pub result_sets: Vec<ResultSet>, pub status: Option<Status>, pub precommit_token: Option<MultiplexedSessionPrecommitToken>, /* private fields */ }
The response for ExecuteBatchDml. Contains a list of ResultSet messages, one for each DML statement that has successfully executed, in the same order as the statements in the request. If a statement fails, the status in the response body identifies the cause of the failure.

To check for DML statements that failed, use the following approach:

  1. Check the status in the response message. The [google.rpc.Code][google.rpc.Code] enum value OK indicates that all statements were executed successfully.
  2. If the status was not OK, check the number of result sets in the response. If the response contains N ResultSet messages, then statement N+1 in the request failed.

Example 1:

  • Request: 5 DML statements, all executed successfully.
  • Response: 5 ResultSet messages, with the status OK.

Example 2:

  • Request: 5 DML statements. The third statement has a syntax error.
  • Response: 2 ResultSet messages, and a syntax error (INVALID_ARGUMENT) status. The number of ResultSet messages indicates that the third statement failed, and the fourth and fifth statements were not executed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
result_sets: Vec<ResultSet>

One ResultSet for each statement in the request that ran successfully, in the same order as the statements in the request. Each ResultSet does not contain any rows. The ResultSetStats in each ResultSet contain the number of rows modified by the statement.

Only the first ResultSet in the response contains valid ResultSetMetadata.

status: Option<Status>

If all DML statements are executed successfully, the status is OK. Otherwise, the error status of the first failed statement.

precommit_token: Option<MultiplexedSessionPrecommitToken>

Optional. A precommit token is included if the read-write transaction is on a multiplexed session. Pass the precommit token with the highest sequence number from this transaction attempt should be passed to the Commit request for this transaction.

Implementations

Source

impl ExecuteBatchDmlResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_result_sets<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ResultSet>,

Sets the value of result_sets.

pub fn set_status<T>(self, v: T) -> Self
where T: Into<Status>,

Sets the value of status.

pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
where T: Into<Status>,

Sets or clears the value of status.

pub fn set_precommit_token<T>(self, v: T) -> Self

Sets the value of precommit_token.

pub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Self

Sets or clears the value of precommit_token.