#[non_exhaustive]pub struct FetchCacheUpdateRequest {
pub database: String,
pub max_recipe_count: i32,
pub max_range_count: i32,
/* private fields */
}Expand description
The request for [FetchCacheUpdate][google.spanner.v1.Spanner.FetchCacheUpdate].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database: StringRequired. The database for which to retrieve the cache update.
max_recipe_count: i32Optional. The maximum number of key recipes to return in the response. If not set, a default limit of 100 will be used.
max_range_count: i32Optional. The maximum number of ranges to return in the response. If not set, a default limit of 10000 will be used.
Implementations
Sourceimpl FetchCacheUpdateRequest
impl FetchCacheUpdateRequest
Sourcepub fn set_database<T: Into<String>>(self, v: T) -> Self
pub fn set_database<T: Into<String>>(self, v: T) -> Self
Sets the value of database.
Sourcepub fn set_max_recipe_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_recipe_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_recipe_count.
Sourcepub fn set_max_range_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_range_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_range_count.