#[non_exhaustive]pub struct Group {
pub group_uid: u64,
pub tablets: Vec<Tablet>,
pub leader_index: i32,
pub generation: Bytes,
/* private fields */
}Expand description
A Group represents a paxos group in a database. A group is a set of
tablets that are replicated across multiple servers. Groups may have a leader
tablet. Groups store one (or sometimes more) ranges of keys.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_uid: u64The UID of the paxos group, unique within the database. Matches the
group_uid field in Range.
tablets: Vec<Tablet>A list of tablets that are part of the group. Note that this list may not be exhaustive; it will only include tablets the server considers useful to the client. The returned list is ordered ascending by distance.
Tablet UIDs reference Tablet.tablet_uid.
leader_index: i32The last known leader tablet of the group as an index into tablets. May
be negative if the group has no known leader.
generation: Bytesgeneration indicates the freshness of the group information (including
leader information) contained in this proto. Generations can be compared
lexicographically; if generation A is greater than generation B, then the
Group corresponding to A is newer than the Group corresponding to B,
and should be used preferentially.
Implementations
Sourceimpl Group
impl Group
Sourcepub fn set_group_uid<T: Into<u64>>(self, v: T) -> Self
pub fn set_group_uid<T: Into<u64>>(self, v: T) -> Self
Sets the value of group_uid.
Sourcepub fn set_tablets<T, V>(self, v: T) -> Self
pub fn set_tablets<T, V>(self, v: T) -> Self
Sets the value of tablets.
Sourcepub fn set_leader_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_leader_index<T: Into<i32>>(self, v: T) -> Self
Sets the value of leader_index.
Sourcepub fn set_generation<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_generation<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of generation.