KeyRange

Struct KeyRange 

#[non_exhaustive]
pub struct KeyRange { pub start_key_type: Option<StartKeyType>, pub end_key_type: Option<EndKeyType>, /* private fields */ }
KeyRange represents a range of rows in a table or index.

A range has a start key and an end key. These keys can be open or closed, indicating if the range includes rows with that key.

Keys are represented by lists, where the ith value in the list corresponds to the ith component of the table or index primary key. Individual values are encoded as described here.

For example, consider the following table definition:

CREATE TABLE UserEvents (
  UserName STRING(MAX),
  EventDate STRING(10)
) PRIMARY KEY(UserName, EventDate);

The following keys name rows in this table:

["Bob", "2014-09-23"]
["Alfred", "2015-06-12"]

Since the UserEvents table’s PRIMARY KEY clause names two columns, each UserEvents key has two elements; the first is the UserName, and the second is the EventDate.

Key ranges with multiple components are interpreted lexicographically by component using the table or index key’s declared sort order. For example, the following range returns all events for user "Bob" that occurred in the year 2015:

"start_closed": ["Bob", "2015-01-01"]
"end_closed": ["Bob", "2015-12-31"]

Start and end keys can omit trailing key components. This affects the inclusion and exclusion of rows that exactly match the provided key components: if the key is closed, then rows that exactly match the provided components are included; if the key is open, then rows that exactly match are not included.

For example, the following range includes all events for "Bob" that occurred during and after the year 2000:

"start_closed": ["Bob", "2000-01-01"]
"end_closed": ["Bob"]

The next example retrieves all events for "Bob":

"start_closed": ["Bob"]
"end_closed": ["Bob"]

To retrieve events before the year 2000:

"start_closed": ["Bob"]
"end_open": ["Bob", "2000-01-01"]

The following range includes all rows in the table:

"start_closed": []
"end_closed": []

This range returns all users whose UserName begins with any character from A to C:

"start_closed": ["A"]
"end_open": ["D"]

This range returns all users whose UserName begins with B:

"start_closed": ["B"]
"end_open": ["C"]

Key ranges honor column sort order. For example, suppose a table is defined as follows:

CREATE TABLE DescendingSortedTable {
  Key INT64,
  ...
) PRIMARY KEY(Key DESC);

The following range retrieves all rows with key values between 1 and 100 inclusive:

"start_closed": ["100"]
"end_closed": ["1"]

Note that 100 is passed as the start, and 1 is passed as the end, because Key is a descending column in the schema.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
start_key_type: Option<StartKeyType>

The start key must be provided. It can be either closed or open.

end_key_type: Option<EndKeyType>

The end key must be provided. It can be either closed or open.

Implementations

Source

impl KeyRange

pub fn new() -> Self

Creates a new default instance.

pub fn set_start_key_type<T: Into<Option<StartKeyType>>>(self, v: T) -> Self

Sets the value of start_key_type.

Note that all the setters affecting start_key_type are mutually exclusive.

pub fn start_closed(&self) -> Option<&Box<ListValue>>

The value of start_key_type if it holds a StartClosed, None if the field is not set or holds a different branch.

pub fn set_start_closed<T: Into<Box<ListValue>>>(self, v: T) -> Self

Sets the value of start_key_type to hold a StartClosed.

Note that all the setters affecting start_key_type are mutually exclusive.

pub fn start_open(&self) -> Option<&Box<ListValue>>

The value of start_key_type if it holds a StartOpen, None if the field is not set or holds a different branch.

pub fn set_start_open<T: Into<Box<ListValue>>>(self, v: T) -> Self

Sets the value of start_key_type to hold a StartOpen.

Note that all the setters affecting start_key_type are mutually exclusive.

pub fn set_end_key_type<T: Into<Option<EndKeyType>>>(self, v: T) -> Self

Sets the value of end_key_type.

Note that all the setters affecting end_key_type are mutually exclusive.

pub fn end_closed(&self) -> Option<&Box<ListValue>>

The value of end_key_type if it holds a EndClosed, None if the field is not set or holds a different branch.

pub fn set_end_closed<T: Into<Box<ListValue>>>(self, v: T) -> Self

Sets the value of end_key_type to hold a EndClosed.

Note that all the setters affecting end_key_type are mutually exclusive.

pub fn end_open(&self) -> Option<&Box<ListValue>>

The value of end_key_type if it holds a EndOpen, None if the field is not set or holds a different branch.

pub fn set_end_open<T: Into<Box<ListValue>>>(self, v: T) -> Self

Sets the value of end_key_type to hold a EndOpen.

Note that all the setters affecting end_key_type are mutually exclusive.