#[non_exhaustive]pub struct ListSessionsRequest {
pub database: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
The request for ListSessions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database: StringRequired. The database in which to list sessions.
page_size: i32Number of sessions to be returned in the response. If 0 or less, defaults to the server’s maximum allowed page size.
page_token: StringIf non-empty, page_token should contain a
next_page_token
from a previous
ListSessionsResponse.
filter: StringAn expression for filtering the results of the request. Filter rules are case insensitive. The fields eligible for filtering are:
labels.keywhere key is the name of a label
Some examples of using filters are:
labels.env:*–> The session has the label “env”.labels.env:dev–> The session has the label “env” and the value of the label contains the string “dev”.
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
Sourcepub fn set_database<T: Into<String>>(self, v: T) -> Self
pub fn set_database<T: Into<String>>(self, v: T) -> Self
Sets the value of database.
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sets the value of page_size.
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sets the value of filter.