PartialResultSet

Struct PartialResultSet 

#[non_exhaustive]
pub struct PartialResultSet { pub metadata: Option<ResultSetMetadata>, pub values: Vec<Value>, pub chunked_value: bool, pub resume_token: Bytes, pub stats: Option<ResultSetStats>, pub precommit_token: Option<MultiplexedSessionPrecommitToken>, pub last: bool, pub cache_update: Option<CacheUpdate>, /* private fields */ }
Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
metadata: Option<ResultSetMetadata>

Metadata about the result set, such as row type information. Only present in the first response.

values: Vec<Value>

A streamed result set consists of a stream of values, which might be split into many PartialResultSet messages to accommodate large rows and/or large values. Every N complete values defines a row, where N is equal to the number of entries in metadata.row_type.fields.

Most values are encoded based on type as described here.

It’s possible that the last value in values is “chunked”, meaning that the rest of the value is sent in subsequent PartialResultSet(s). This is denoted by the chunked_value field. Two or more chunked values can be merged to form a complete value as follows:

  • bool/number/null: can’t be chunked
  • string: concatenate the strings
  • list: concatenate the lists. If the last element in a list is a string, list, or object, merge it with the first element in the next list by applying these rules recursively.
  • object: concatenate the (field name, field value) pairs. If a field name is duplicated, then apply these rules recursively to merge the field values.

Some examples of merging:

Strings are concatenated.
"foo", "bar" => "foobar"

Lists of non-strings are concatenated.
[2, 3], [4] => [2, 3, 4]

Lists are concatenated, but the last and first elements are merged
because they are strings.
["a", "b"], ["c", "d"] => ["a", "bc", "d"]

Lists are concatenated, but the last and first elements are merged
because they are lists. Recursively, the last and first elements
of the inner lists are merged because they are strings.
["a", ["b", "c"]], [["d"], "e"] => ["a", ["b", "cd"], "e"]

Non-overlapping object fields are combined.
{"a": "1"}, {"b": "2"} => {"a": "1", "b": 2"}

Overlapping object fields are merged.
{"a": "1"}, {"a": "2"} => {"a": "12"}

Examples of merging objects containing lists of strings.
{"a": ["1"]}, {"a": ["2"]} => {"a": ["12"]}

For a more complete example, suppose a streaming SQL query is yielding a result set whose rows contain a single string field. The following PartialResultSets might be yielded:

{
  "metadata": { ... }
  "values": ["Hello", "W"]
  "chunked_value": true
  "resume_token": "Af65..."
}
{
  "values": ["orl"]
  "chunked_value": true
}
{
  "values": ["d"]
  "resume_token": "Zx1B..."
}

This sequence of PartialResultSets encodes two rows, one containing the field value "Hello", and a second containing the field value "World" = "W" + "orl" + "d".

Not all PartialResultSets contain a resume_token. Execution can only be resumed from a previously yielded resume_token. For the above sequence of PartialResultSets, resuming the query with "resume_token": "Af65..." yields results from the PartialResultSet with value “orl”.

chunked_value: bool

If true, then the final value in values is chunked, and must be combined with more values from subsequent PartialResultSets to obtain a complete field value.

resume_token: Bytes

Streaming calls might be interrupted for a variety of reasons, such as TCP connection loss. If this occurs, the stream of results can be resumed by re-sending the original request and including resume_token. Note that executing any other transaction in the same session invalidates the token.

stats: Option<ResultSetStats>

Query plan and execution statistics for the statement that produced this streaming result set. These can be requested by setting ExecuteSqlRequest.query_mode and are sent only once with the last response in the stream. This field is also present in the last response for DML statements.

precommit_token: Option<MultiplexedSessionPrecommitToken>

Optional. A precommit token is included if the read-write transaction has multiplexed sessions enabled. Pass the precommit token with the highest sequence number from this transaction attempt to the Commit request for this transaction.

last: bool

Optional. Indicates whether this is the last PartialResultSet in the stream. The server might optionally set this field. Clients shouldn’t rely on this field being set in all cases.

cache_update: Option<CacheUpdate>

Optional. A cache update expresses a set of changes the client should incorporate into its location cache. The client should discard the changes if they are older than the data it already has. This data can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.

Implementations

Source

impl PartialResultSet

pub fn new() -> Self

Creates a new default instance.

pub fn set_metadata<T>(self, v: T) -> Self

Sets the value of metadata.

pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self

Sets or clears the value of metadata.

pub fn set_values<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Value>,

Sets the value of values.

pub fn set_chunked_value<T: Into<bool>>(self, v: T) -> Self

Sets the value of chunked_value.

pub fn set_resume_token<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of resume_token.

pub fn set_stats<T>(self, v: T) -> Self
where T: Into<ResultSetStats>,

Sets the value of stats.

pub fn set_or_clear_stats<T>(self, v: Option<T>) -> Self
where T: Into<ResultSetStats>,

Sets or clears the value of stats.

pub fn set_precommit_token<T>(self, v: T) -> Self

Sets the value of precommit_token.

pub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Self

Sets or clears the value of precommit_token.

pub fn set_last<T: Into<bool>>(self, v: T) -> Self

Sets the value of last.

pub fn set_cache_update<T>(self, v: T) -> Self
where T: Into<CacheUpdate>,

Sets the value of cache_update.

pub fn set_or_clear_cache_update<T>(self, v: Option<T>) -> Self
where T: Into<CacheUpdate>,

Sets or clears the value of cache_update.