#[non_exhaustive]pub struct Partition {
pub partition_token: Bytes,
/* private fields */
}Expand description
Information returned for each partition returned in a PartitionResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.partition_token: BytesThis token can be passed to Read, StreamingRead, ExecuteSql, or
ExecuteStreamingSql requests to restrict the results to those identified
by this partition token.
Implementations
Sourceimpl Partition
impl Partition
Sourcepub fn set_partition_token<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_partition_token<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of partition_token.