#[non_exhaustive]pub struct PartitionOptions {
pub partition_size_bytes: i64,
pub max_partitions: i64,
/* private fields */
}Expand description
Options for a PartitionQueryRequest and PartitionReadRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.partition_size_bytes: i64Note: This hint is currently ignored by PartitionQuery and
PartitionRead requests.
The desired data size for each partition generated. The default for this option is currently 1 GiB. This is only a hint. The actual size of each partition can be smaller or larger than this size request.
max_partitions: i64Note: This hint is currently ignored by PartitionQuery and
PartitionRead requests.
The desired maximum number of partitions to return. For example, this might be set to the number of workers available. The default for this option is currently 10,000. The maximum value is currently 200,000. This is only a hint. The actual number of partitions returned can be smaller or larger than this maximum count request.
Implementations
Sourceimpl PartitionOptions
impl PartitionOptions
Sourcepub fn set_partition_size_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_partition_size_bytes<T: Into<i64>>(self, v: T) -> Self
Sets the value of partition_size_bytes.
Sourcepub fn set_max_partitions<T: Into<i64>>(self, v: T) -> Self
pub fn set_max_partitions<T: Into<i64>>(self, v: T) -> Self
Sets the value of max_partitions.