PartitionQueryRequest

Struct PartitionQueryRequest 

#[non_exhaustive]
pub struct PartitionQueryRequest { pub session: String, pub transaction: Option<TransactionSelector>, pub sql: String, pub params: Option<Struct>, pub param_types: HashMap<String, Type>, pub partition_options: Option<PartitionOptions>, /* private fields */ }
The request for PartitionQuery

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session used to create the partitions.

transaction: Option<TransactionSelector>

Read-only snapshot transactions are supported, read and write and single-use transactions are not.

sql: String

Required. The query request to generate partitions for. The request fails if the query isn’t root partitionable. For a query to be root partitionable, it needs to satisfy a few conditions. For example, if the query execution plan contains a distributed union operator, then it must be the first operator in the plan. For more information about other conditions, see Read data in parallel.

The query request must not contain DML commands, such as INSERT, UPDATE, or DELETE. Use [ExecuteStreamingSql][google.spanner.v1.Spanner.ExecuteStreamingSql] with a PartitionedDml transaction for large, partition-friendly DML operations.

params: Option<Struct>

Optional. Parameter names and values that bind to placeholders in the SQL string.

A parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName). Parameter names can contain letters, numbers, and underscores.

Parameters can appear anywhere that a literal value is expected. The same parameter name can be used more than once, for example:

"WHERE id > @msg_id AND id < @msg_id + 100"

It’s an error to execute a SQL statement with unbound parameters.

param_types: HashMap<String, Type>

Optional. It isn’t always possible for Cloud Spanner to infer the right SQL type from a JSON value. For example, values of type BYTES and values of type STRING both appear in params as JSON strings.

In these cases, param_types can be used to specify the exact SQL type for some or all of the SQL query parameters. See the definition of Type for more information about SQL types.

partition_options: Option<PartitionOptions>

Additional options that affect how many partitions are created.

Implementations

Source

impl PartitionQueryRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_transaction<T>(self, v: T) -> Self

Sets the value of transaction.

pub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Self

Sets or clears the value of transaction.

pub fn set_sql<T: Into<String>>(self, v: T) -> Self

Sets the value of sql.

pub fn set_params<T>(self, v: T) -> Self
where T: Into<Struct>,

Sets the value of params.

pub fn set_or_clear_params<T>(self, v: Option<T>) -> Self
where T: Into<Struct>,

Sets or clears the value of params.

pub fn set_param_types<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<Type>,

Sets the value of param_types.

pub fn set_partition_options<T>(self, v: T) -> Self

Sets the value of partition_options.

pub fn set_or_clear_partition_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of partition_options.