#[non_exhaustive]pub struct PartitionReadRequest {
pub session: String,
pub transaction: Option<TransactionSelector>,
pub table: String,
pub index: String,
pub columns: Vec<String>,
pub key_set: Option<KeySet>,
pub partition_options: Option<PartitionOptions>,
/* private fields */
}Expand description
The request for PartitionRead
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session: StringRequired. The session used to create the partitions.
transaction: Option<TransactionSelector>Read only snapshot transactions are supported, read/write and single use transactions are not.
table: StringRequired. The name of the table in the database to be read.
index: StringIf non-empty, the name of an index on table. This index is used instead of the table primary key when interpreting key_set and sorting result rows. See key_set for further information.
columns: Vec<String>The columns of table to be returned for each row matching this request.
key_set: Option<KeySet>Required. key_set identifies the rows to be yielded. key_set names the
primary keys of the rows in
table to be yielded, unless
index is present. If
index is present, then
key_set instead names
index keys in index.
It isn’t an error for the key_set to name rows that don’t
exist in the database. Read yields nothing for nonexistent rows.
partition_options: Option<PartitionOptions>Additional options that affect how many partitions are created.
Implementations
Sourceimpl PartitionReadRequest
impl PartitionReadRequest
Sourcepub fn set_session<T: Into<String>>(self, v: T) -> Self
pub fn set_session<T: Into<String>>(self, v: T) -> Self
Sets the value of session.
Sourcepub fn set_transaction<T>(self, v: T) -> Selfwhere
T: Into<TransactionSelector>,
pub fn set_transaction<T>(self, v: T) -> Selfwhere
T: Into<TransactionSelector>,
Sets the value of transaction.
Sourcepub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransactionSelector>,
pub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransactionSelector>,
Sets or clears the value of transaction.
Sourcepub fn set_columns<T, V>(self, v: T) -> Self
pub fn set_columns<T, V>(self, v: T) -> Self
Sets the value of columns.
Sourcepub fn set_key_set<T>(self, v: T) -> Self
pub fn set_key_set<T>(self, v: T) -> Self
Sets the value of key_set.
Sourcepub fn set_or_clear_key_set<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_key_set<T>(self, v: Option<T>) -> Self
Sets or clears the value of key_set.
Sourcepub fn set_partition_options<T>(self, v: T) -> Selfwhere
T: Into<PartitionOptions>,
pub fn set_partition_options<T>(self, v: T) -> Selfwhere
T: Into<PartitionOptions>,
Sets the value of partition_options.
Sourcepub fn set_or_clear_partition_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<PartitionOptions>,
pub fn set_or_clear_partition_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<PartitionOptions>,
Sets or clears the value of partition_options.