PlanNode

Struct PlanNode 

#[non_exhaustive]
pub struct PlanNode { pub index: i32, pub kind: Kind, pub display_name: String, pub child_links: Vec<ChildLink>, pub short_representation: Option<ShortRepresentation>, pub metadata: Option<Struct>, pub execution_stats: Option<Struct>, /* private fields */ }
Node information for nodes appearing in a QueryPlan.plan_nodes.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
index: i32

The PlanNode’s index in node list.

kind: Kind

Used to determine the type of node. May be needed for visualizing different kinds of nodes differently. For example, If the node is a SCALAR node, it will have a condensed representation which can be used to directly embed a description of the node in its parent.

display_name: String

The display name for the node.

child_links: Vec<ChildLink>

List of child node indexes and their relationship to this parent.

short_representation: Option<ShortRepresentation>

Condensed representation for SCALAR nodes.

metadata: Option<Struct>

Attributes relevant to the node contained in a group of key-value pairs. For example, a Parameter Reference node could have the following information in its metadata:

{
  "parameter_reference": "param1",
  "parameter_type": "array"
}
execution_stats: Option<Struct>

The execution statistics associated with the node, contained in a group of key-value pairs. Only present if the plan was returned as a result of a profile query. For example, number of executions, number of rows/time per execution etc.

Implementations

Source

impl PlanNode

pub fn new() -> Self

Creates a new default instance.

pub fn set_index<T: Into<i32>>(self, v: T) -> Self

Sets the value of index.

pub fn set_kind<T: Into<Kind>>(self, v: T) -> Self

Sets the value of kind.

pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Sets the value of child_links.

pub fn set_short_representation<T>(self, v: T) -> Self

Sets the value of short_representation.

pub fn set_or_clear_short_representation<T>(self, v: Option<T>) -> Self

Sets or clears the value of short_representation.

pub fn set_metadata<T>(self, v: T) -> Self
where T: Into<Struct>,

Sets the value of metadata.

pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
where T: Into<Struct>,

Sets or clears the value of metadata.

pub fn set_execution_stats<T>(self, v: T) -> Self
where T: Into<Struct>,

Sets the value of execution_stats.

pub fn set_or_clear_execution_stats<T>(self, v: Option<T>) -> Self
where T: Into<Struct>,

Sets or clears the value of execution_stats.