#[non_exhaustive]pub struct QueryAdvisorResult {
pub index_advice: Vec<IndexAdvice>,
/* private fields */
}Expand description
Output of query advisor analysis.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index_advice: Vec<IndexAdvice>Optional. Index Recommendation for a query. This is an optional field and the recommendation will only be available when the recommendation guarantees significant improvement in query performance.
Implementations
Sourceimpl QueryAdvisorResult
impl QueryAdvisorResult
Sourcepub fn set_index_advice<T, V>(self, v: T) -> Self
pub fn set_index_advice<T, V>(self, v: T) -> Self
Sets the value of index_advice.