#[non_exhaustive]pub struct QueryPlan {
pub plan_nodes: Vec<PlanNode>,
pub query_advice: Option<QueryAdvisorResult>,
/* private fields */
}Expand description
Contains an ordered list of nodes appearing in the query plan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plan_nodes: Vec<PlanNode>The nodes in the query plan. Plan nodes are returned in pre-order starting
with the plan root. Each PlanNode’s id
corresponds to its index in plan_nodes.
query_advice: Option<QueryAdvisorResult>Optional. The advise/recommendations for a query. Currently this field will be serving index recommendations for a query.
Implementations
Sourceimpl QueryPlan
impl QueryPlan
Sourcepub fn set_plan_nodes<T, V>(self, v: T) -> Self
pub fn set_plan_nodes<T, V>(self, v: T) -> Self
Sets the value of plan_nodes.
Sourcepub fn set_query_advice<T>(self, v: T) -> Selfwhere
T: Into<QueryAdvisorResult>,
pub fn set_query_advice<T>(self, v: T) -> Selfwhere
T: Into<QueryAdvisorResult>,
Sets the value of query_advice.
Sourcepub fn set_or_clear_query_advice<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryAdvisorResult>,
pub fn set_or_clear_query_advice<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryAdvisorResult>,
Sets or clears the value of query_advice.