ReadRequest

Struct ReadRequest 

#[non_exhaustive]
pub struct ReadRequest {
Show 15 fields pub session: String, pub transaction: Option<TransactionSelector>, pub table: String, pub index: String, pub columns: Vec<String>, pub key_set: Option<KeySet>, pub limit: i64, pub resume_token: Bytes, pub partition_token: Bytes, pub request_options: Option<RequestOptions>, pub directed_read_options: Option<DirectedReadOptions>, pub data_boost_enabled: bool, pub order_by: OrderBy, pub lock_hint: LockHint, pub routing_hint: Option<RoutingHint>, /* private fields */
}
The request for Read and [StreamingRead][google.spanner.v1.Spanner.StreamingRead].

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session in which the read should be performed.

transaction: Option<TransactionSelector>

The transaction to use. If none is provided, the default is a temporary read-only transaction with strong concurrency.

table: String

Required. The name of the table in the database to be read.

index: String

If non-empty, the name of an index on table. This index is used instead of the table primary key when interpreting key_set and sorting result rows. See key_set for further information.

columns: Vec<String>

Required. The columns of table to be returned for each row matching this request.

key_set: Option<KeySet>

Required. key_set identifies the rows to be yielded. key_set names the primary keys of the rows in table to be yielded, unless index is present. If index is present, then key_set instead names index keys in index.

If the partition_token field is empty, rows are yielded in table primary key order (if index is empty) or index key order (if index is non-empty). If the partition_token field isn’t empty, rows are yielded in an unspecified order.

It isn’t an error for the key_set to name rows that don’t exist in the database. Read yields nothing for nonexistent rows.

limit: i64

If greater than zero, only the first limit rows are yielded. If limit is zero, the default is no limit. A limit can’t be specified if partition_token is set.

resume_token: Bytes

If this request is resuming a previously interrupted read, resume_token should be copied from the last PartialResultSet yielded before the interruption. Doing this enables the new read to resume where the last read left off. The rest of the request parameters must exactly match the request that yielded this token.

partition_token: Bytes

If present, results are restricted to the specified partition previously created using PartitionRead. There must be an exact match for the values of fields common to this message and the PartitionReadRequest message used to create this partition_token.

request_options: Option<RequestOptions>

Common options for this request.

directed_read_options: Option<DirectedReadOptions>

Directed read options for this request.

data_boost_enabled: bool

If this is for a partitioned read and this field is set to true, the request is executed with Spanner Data Boost independent compute resources.

If the field is set to true but the request doesn’t set partition_token, the API returns an INVALID_ARGUMENT error.

order_by: OrderBy

Optional. Order for the returned rows.

By default, Spanner returns result rows in primary key order except for PartitionRead requests. For applications that don’t require rows to be returned in primary key (ORDER_BY_PRIMARY_KEY) order, setting ORDER_BY_NO_ORDER option allows Spanner to optimize row retrieval, resulting in lower latencies in certain cases (for example, bulk point lookups).

lock_hint: LockHint

Optional. Lock Hint for the request, it can only be used with read-write transactions.

routing_hint: Option<RoutingHint>

Optional. Makes the Spanner requests location-aware if present.

It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.

Implementations

Source

impl ReadRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_transaction<T>(self, v: T) -> Self

Sets the value of transaction.

pub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Self

Sets or clears the value of transaction.

pub fn set_table<T: Into<String>>(self, v: T) -> Self

Sets the value of table.

pub fn set_index<T: Into<String>>(self, v: T) -> Self

Sets the value of index.

pub fn set_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of columns.

pub fn set_key_set<T>(self, v: T) -> Self
where T: Into<KeySet>,

Sets the value of key_set.

pub fn set_or_clear_key_set<T>(self, v: Option<T>) -> Self
where T: Into<KeySet>,

Sets or clears the value of key_set.

pub fn set_limit<T: Into<i64>>(self, v: T) -> Self

Sets the value of limit.

pub fn set_resume_token<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of resume_token.

pub fn set_partition_token<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of partition_token.

pub fn set_request_options<T>(self, v: T) -> Self
where T: Into<RequestOptions>,

Sets the value of request_options.

pub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Self
where T: Into<RequestOptions>,

Sets or clears the value of request_options.

pub fn set_directed_read_options<T>(self, v: T) -> Self

Sets the value of directed_read_options.

pub fn set_or_clear_directed_read_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of directed_read_options.

pub fn set_data_boost_enabled<T: Into<bool>>(self, v: T) -> Self

Sets the value of data_boost_enabled.

pub fn set_order_by<T: Into<OrderBy>>(self, v: T) -> Self

Sets the value of order_by.

pub fn set_lock_hint<T: Into<LockHint>>(self, v: T) -> Self

Sets the value of lock_hint.

pub fn set_routing_hint<T>(self, v: T) -> Self
where T: Into<RoutingHint>,

Sets the value of routing_hint.

pub fn set_or_clear_routing_hint<T>(self, v: Option<T>) -> Self
where T: Into<RoutingHint>,

Sets or clears the value of routing_hint.