#[non_exhaustive]pub struct RecipeList {
pub schema_generation: Bytes,
pub recipe: Vec<KeyRecipe>,
/* private fields */
}Expand description
A RecipeList contains a list of KeyRecipes, which share the same
schema generation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_generation: BytesThe schema generation of the recipes. To be sent to the server in
RoutingHint.schema_generation whenever one of the recipes is used.
schema_generation values are comparable with each other; if generation A
compares greater than generation B, then A is a more recent schema than B.
Clients should in general aim to cache only the latest schema generation,
and discard more stale recipes.
recipe: Vec<KeyRecipe>A list of recipes to be cached.
Implementations
Sourceimpl RecipeList
impl RecipeList
Sourcepub fn set_schema_generation<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_schema_generation<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of schema_generation.
Sourcepub fn set_recipe<T, V>(self, v: T) -> Self
pub fn set_recipe<T, V>(self, v: T) -> Self
Sets the value of recipe.