ResultSetMetadata

Struct ResultSetMetadata 

#[non_exhaustive]
pub struct ResultSetMetadata { pub row_type: Option<StructType>, pub transaction: Option<Transaction>, pub undeclared_parameters: Option<StructType>, /* private fields */ }
Metadata about a ResultSet or PartialResultSet.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
row_type: Option<StructType>

Indicates the field names and types for the rows in the result set. For example, a SQL query like "SELECT UserId, UserName FROM Users" could return a row_type value like:

"fields": [
  { "name": "UserId", "type": { "code": "INT64" } },
  { "name": "UserName", "type": { "code": "STRING" } },
]
transaction: Option<Transaction>

If the read or SQL query began a transaction as a side-effect, the information about the new transaction is yielded here.

undeclared_parameters: Option<StructType>

A SQL query can be parameterized. In PLAN mode, these parameters can be undeclared. This indicates the field names and types for those undeclared parameters in the SQL query. For example, a SQL query like "SELECT * FROM Users where UserId = @userId and UserName = @userName " could return a undeclared_parameters value like:

"fields": [
  { "name": "UserId", "type": { "code": "INT64" } },
  { "name": "UserName", "type": { "code": "STRING" } },
]

Implementations

Source

impl ResultSetMetadata

pub fn new() -> Self

Creates a new default instance.

pub fn set_row_type<T>(self, v: T) -> Self
where T: Into<StructType>,

Sets the value of row_type.

pub fn set_or_clear_row_type<T>(self, v: Option<T>) -> Self
where T: Into<StructType>,

Sets or clears the value of row_type.

pub fn set_transaction<T>(self, v: T) -> Self
where T: Into<Transaction>,

Sets the value of transaction.

pub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Self
where T: Into<Transaction>,

Sets or clears the value of transaction.

pub fn set_undeclared_parameters<T>(self, v: T) -> Self
where T: Into<StructType>,

Sets the value of undeclared_parameters.

pub fn set_or_clear_undeclared_parameters<T>(self, v: Option<T>) -> Self
where T: Into<StructType>,

Sets or clears the value of undeclared_parameters.