#[non_exhaustive]pub struct StructType {
pub fields: Vec<Field>,
/* private fields */
}Expand description
StructType defines the fields of a
STRUCT type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fields: Vec<Field>The list of fields that make up this struct. Order is
significant, because values of this struct type are represented as
lists, where the order of field values matches the order of
fields in the StructType. In turn, the
order of fields matches the order of columns in a read request, or the
order of fields in the SELECT clause of a query.
Implementations
Sourceimpl StructType
impl StructType
Sourcepub fn set_fields<T, V>(self, v: T) -> Self
pub fn set_fields<T, V>(self, v: T) -> Self
Sets the value of fields.