Tablet

Struct Tablet 

#[non_exhaustive]
pub struct Tablet { pub tablet_uid: u64, pub server_address: String, pub location: String, pub role: Role, pub incarnation: Bytes, pub distance: u32, pub skip: bool, /* private fields */ }
A Tablet represents a single replica of a Group. A tablet is served by a single server at a time, and can move between servers due to server death or simply load balancing.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tablet_uid: u64

The UID of the tablet, unique within the database. Matches the tablet_uids and leader_tablet_uid fields in Group.

server_address: String

The address of the server that is serving this tablet – either an IP address or DNS hostname and a port number.

location: String

Where this tablet is located. This is the name of a Google Cloud region, such as “us-central1”.

role: Role

The role of the tablet.

incarnation: Bytes

incarnation indicates the freshness of the tablet information contained in this proto. Incarnations can be compared lexicographically; if incarnation A is greater than incarnation B, then the Tablet corresponding to A is newer than the Tablet corresponding to B, and should be used preferentially.

distance: u32

Distances help the client pick the closest tablet out of the list of tablets for a given request. Tablets with lower distances should generally be preferred. Tablets with the same distance are approximately equally close; the client can choose arbitrarily.

Distances do not correspond precisely to expected latency, geographical distance, or anything else. Distances should be compared only between tablets of the same group; they are not meaningful between different groups.

A value of zero indicates that the tablet may be in the same zone as the client, and have minimum network latency. A value less than or equal to five indicates that the tablet is thought to be in the same region as the client, and may have a few milliseconds of network latency. Values greater than five are most likely in a different region, with non-trivial network latency.

Clients should use the following algorithm:

  • If the request is using a directed read, eliminate any tablets that do not match the directed read’s target zone and/or replica type.
  • (Read-write transactions only) Choose leader tablet if it has an distance <=5.
  • Group and sort tablets by distance. Choose a random tablet with the lowest distance. If the request is not a directed read, only consider replicas with distances <=5.
  • Send the request to the fallback endpoint.

The tablet picked by this algorithm may be skipped, either because it is marked as skip by the server or because the corresponding server is unreachable, flow controlled, etc. Skipped tablets should be added to the skipped_tablet_uid field in RoutingHint; the algorithm above should then be re-run without including the skipped tablet(s) to pick the next best tablet.

skip: bool

If true, the tablet should not be chosen by the client. Typically, this signals that the tablet is unhealthy in some way. Tablets with skip set to true should be reported back to the server in RoutingHint.skipped_tablet_uid; this cues the server to send updated information for this tablet should it become usable again.

Implementations

Source

impl Tablet

pub fn new() -> Self

Creates a new default instance.

pub fn set_tablet_uid<T: Into<u64>>(self, v: T) -> Self

Sets the value of tablet_uid.

pub fn set_server_address<T: Into<String>>(self, v: T) -> Self

Sets the value of server_address.

pub fn set_location<T: Into<String>>(self, v: T) -> Self

Sets the value of location.

pub fn set_role<T: Into<Role>>(self, v: T) -> Self

Sets the value of role.

pub fn set_incarnation<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of incarnation.

pub fn set_distance<T: Into<u32>>(self, v: T) -> Self

Sets the value of distance.

pub fn set_skip<T: Into<bool>>(self, v: T) -> Self

Sets the value of skip.