Transaction

Struct Transaction 

#[non_exhaustive]
pub struct Transaction { pub id: Bytes, pub read_timestamp: Option<Timestamp>, pub precommit_token: Option<MultiplexedSessionPrecommitToken>, pub cache_update: Option<CacheUpdate>, /* private fields */ }
A transaction.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Bytes

id may be used to identify the transaction in subsequent Read, ExecuteSql, Commit, or Rollback calls.

Single-use read-only transactions do not have IDs, because single-use transactions do not support multiple requests.

read_timestamp: Option<Timestamp>

For snapshot read-only transactions, the read timestamp chosen for the transaction. Not returned by default: see TransactionOptions.ReadOnly.return_read_timestamp.

A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".

precommit_token: Option<MultiplexedSessionPrecommitToken>

A precommit token is included in the response of a BeginTransaction request if the read-write transaction is on a multiplexed session and a mutation_key was specified in the BeginTransaction. The precommit token with the highest sequence number from this transaction attempt should be passed to the Commit request for this transaction.

cache_update: Option<CacheUpdate>

Optional. A cache update expresses a set of changes the client should incorporate into its location cache. The client should discard the changes if they are older than the data it already has. This data can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.

Implementations

Source

impl Transaction

pub fn new() -> Self

Creates a new default instance.

pub fn set_id<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of id.

pub fn set_read_timestamp<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of read_timestamp.

pub fn set_or_clear_read_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of read_timestamp.

pub fn set_precommit_token<T>(self, v: T) -> Self

Sets the value of precommit_token.

pub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Self

Sets or clears the value of precommit_token.

pub fn set_cache_update<T>(self, v: T) -> Self
where T: Into<CacheUpdate>,

Sets the value of cache_update.

pub fn set_or_clear_cache_update<T>(self, v: Option<T>) -> Self
where T: Into<CacheUpdate>,

Sets or clears the value of cache_update.