#[non_exhaustive]pub struct TransactionOptions {
pub exclude_txn_from_change_streams: bool,
pub isolation_level: IsolationLevel,
pub mode: Option<Mode>,
/* private fields */
}Expand description
Options to use for transactions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.exclude_txn_from_change_streams: boolWhen exclude_txn_from_change_streams is set to true, it prevents read
or write transactions from being tracked in change streams.
-
If the DDL option
allow_txn_exclusionis set totrue, then the updates made within this transaction aren’t recorded in the change stream. -
If you don’t set the DDL option
allow_txn_exclusionor if it’s set tofalse, then the updates made within this transaction are recorded in the change stream.
When exclude_txn_from_change_streams is set to false or not set,
modifications from this transaction are recorded in all change streams
that are tracking columns modified by these transactions.
The exclude_txn_from_change_streams option can only be specified
for read-write or partitioned DML transactions, otherwise the API returns
an INVALID_ARGUMENT error.
isolation_level: IsolationLevelIsolation level for the transaction.
mode: Option<Mode>Required. The type of transaction.
Implementations
Sourceimpl TransactionOptions
impl TransactionOptions
Sourcepub fn set_exclude_txn_from_change_streams<T: Into<bool>>(self, v: T) -> Self
pub fn set_exclude_txn_from_change_streams<T: Into<bool>>(self, v: T) -> Self
Sets the value of exclude_txn_from_change_streams.
Sourcepub fn set_isolation_level<T: Into<IsolationLevel>>(self, v: T) -> Self
pub fn set_isolation_level<T: Into<IsolationLevel>>(self, v: T) -> Self
Sets the value of isolation_level.
Sourcepub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
pub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
Sets the value of mode.
Note that all the setters affecting mode are mutually
exclusive.
Sourcepub fn read_write(&self) -> Option<&Box<ReadWrite>>
pub fn read_write(&self) -> Option<&Box<ReadWrite>>
The value of mode
if it holds a ReadWrite, None if the field is not set or
holds a different branch.
Sourcepub fn set_read_write<T: Into<Box<ReadWrite>>>(self, v: T) -> Self
pub fn set_read_write<T: Into<Box<ReadWrite>>>(self, v: T) -> Self
Sets the value of mode
to hold a ReadWrite.
Note that all the setters affecting mode are
mutually exclusive.
Sourcepub fn partitioned_dml(&self) -> Option<&Box<PartitionedDml>>
pub fn partitioned_dml(&self) -> Option<&Box<PartitionedDml>>
The value of mode
if it holds a PartitionedDml, None if the field is not set or
holds a different branch.
Sourcepub fn set_partitioned_dml<T: Into<Box<PartitionedDml>>>(self, v: T) -> Self
pub fn set_partitioned_dml<T: Into<Box<PartitionedDml>>>(self, v: T) -> Self
Sets the value of mode
to hold a PartitionedDml.
Note that all the setters affecting mode are
mutually exclusive.