#[non_exhaustive]pub struct TransactionSelector {
pub selector: Option<Selector>,
/* private fields */
}Expand description
This message is used to select the transaction in which a Read or ExecuteSql call runs.
See TransactionOptions for more information about transactions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.selector: Option<Selector>If no fields are set, the default is a single use transaction with strong concurrency.
Implementations
Sourceimpl TransactionSelector
impl TransactionSelector
Sourcepub fn set_selector<T: Into<Option<Selector>>>(self, v: T) -> Self
pub fn set_selector<T: Into<Option<Selector>>>(self, v: T) -> Self
Sets the value of selector.
Note that all the setters affecting selector are mutually
exclusive.
Sourcepub fn single_use(&self) -> Option<&Box<TransactionOptions>>
pub fn single_use(&self) -> Option<&Box<TransactionOptions>>
The value of selector
if it holds a SingleUse, None if the field is not set or
holds a different branch.
Sourcepub fn set_single_use<T: Into<Box<TransactionOptions>>>(self, v: T) -> Self
pub fn set_single_use<T: Into<Box<TransactionOptions>>>(self, v: T) -> Self
Sets the value of selector
to hold a SingleUse.
Note that all the setters affecting selector are
mutually exclusive.
Sourcepub fn id(&self) -> Option<&Bytes>
pub fn id(&self) -> Option<&Bytes>
The value of selector
if it holds a Id, None if the field is not set or
holds a different branch.
Sourcepub fn set_id<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_id<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of selector
to hold a Id.
Note that all the setters affecting selector are
mutually exclusive.