#[non_exhaustive]pub enum IsolationLevel {
Unspecified,
Serializable,
RepeatableRead,
UnknownValue(UnknownValue),
}Expand description
IsolationLevel is used when setting the isolation
level for a
transaction.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
If the value is not specified, the SERIALIZABLE isolation level is
used.
Serializable
All transactions appear as if they executed in a serial order, even if some of the reads, writes, and other operations of distinct transactions actually occurred in parallel. Spanner assigns commit timestamps that reflect the order of committed transactions to implement this property. Spanner offers a stronger guarantee than serializability called external consistency. For more information, see TrueTime and external consistency.
RepeatableRead
All reads performed during the transaction observe a consistent snapshot
of the database, and the transaction is only successfully committed in
the absence of conflicts between its updates and any concurrent updates
that have occurred since that snapshot. Consequently, in contrast to
SERIALIZABLE transactions, only write-write conflicts are detected in
snapshot transactions.
This isolation level does not support read-only and partitioned DML transactions.
When REPEATABLE_READ is specified on a read-write transaction, the
locking semantics default to OPTIMISTIC.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using IsolationLevel::value or IsolationLevel::name.
Implementations