TimestampBound

Enum TimestampBound 

#[non_exhaustive]
pub enum TimestampBound { Strong(bool), MinReadTimestamp(Box<Timestamp>), MaxStaleness(Box<Duration>), ReadTimestamp(Box<Timestamp>), ExactStaleness(Box<Duration>), }
How to choose the timestamp for the read-only transaction.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Strong(bool)

Read at a timestamp where all previously committed transactions are visible.



MinReadTimestamp(Box<Timestamp>)

Executes all reads at a timestamp >= min_read_timestamp.

This is useful for requesting fresher data than some previous read, or data that is fresh enough to observe the effects of some previously committed transaction whose timestamp is known.

Note that this option can only be used in single-use transactions.

A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".



MaxStaleness(Box<Duration>)

Read data at a timestamp >= NOW - max_staleness seconds. Guarantees that all writes that have committed more than the specified number of seconds ago are visible. Because Cloud Spanner chooses the exact timestamp, this mode works even if the client’s local clock is substantially skewed from Cloud Spanner commit timestamps.

Useful for reading the freshest data available at a nearby replica, while bounding the possible staleness if the local replica has fallen behind.

Note that this option can only be used in single-use transactions.



ReadTimestamp(Box<Timestamp>)

Executes all reads at the given timestamp. Unlike other modes, reads at a specific timestamp are repeatable; the same read at the same timestamp always returns the same data. If the timestamp is in the future, the read is blocked until the specified timestamp, modulo the read’s deadline.

Useful for large scale consistent reads such as mapreduces, or for coordinating many reads against a consistent snapshot of the data.

A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".



ExactStaleness(Box<Duration>)

Executes all reads at a timestamp that is exact_staleness old. The timestamp is chosen soon after the read is started.

Guarantees that all writes that have committed more than the specified number of seconds ago are visible. Because Cloud Spanner chooses the exact timestamp, this mode works even if the client’s local clock is substantially skewed from Cloud Spanner commit timestamps.

Useful for reading at nearby replicas without the distributed timestamp negotiation overhead of max_staleness.

Implementations

Source

impl TimestampBound

pub fn from_strong(value: impl Into<bool>) -> Self

Initializes the enum to the Strong branch.

pub fn from_min_read_timestamp(value: impl Into<Box<Timestamp>>) -> Self

Initializes the enum to the MinReadTimestamp branch.

pub fn from_max_staleness(value: impl Into<Box<Duration>>) -> Self

Initializes the enum to the MaxStaleness branch.

pub fn from_read_timestamp(value: impl Into<Box<Timestamp>>) -> Self

Initializes the enum to the ReadTimestamp branch.

pub fn from_exact_staleness(value: impl Into<Box<Duration>>) -> Self

Initializes the enum to the ExactStaleness branch.