#[non_exhaustive]pub enum ReadLockMode {
Unspecified,
Pessimistic,
Optimistic,
UnknownValue(UnknownValue),
}Expand description
ReadLockMode is used to set the read lock mode for read-write
transactions.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
- If isolation level is
SERIALIZABLE,
locking semantics default to
PESSIMISTIC. - If isolation level is
REPEATABLE_READ,
locking semantics default to
OPTIMISTIC. - See Concurrency control for more details.
Pessimistic
Pessimistic lock mode.
Lock acquisition behavior depends on the isolation level in use. In SERIALIZABLE isolation, reads and writes acquire necessary locks during transaction statement execution. In REPEATABLE_READ isolation, reads that explicitly request to be locked and writes acquire locks. See Concurrency control for details on the types of locks acquired at each transaction step.
Optimistic
Optimistic lock mode.
Lock acquisition behavior depends on the isolation level in use. In both SERIALIZABLE and REPEATABLE_READ isolation, reads and writes do not acquire locks during transaction statement execution. See Concurrency control for details on how the guarantees of each isolation level are provided at commit time.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ReadLockMode::value or ReadLockMode::name.
Implementations