#[non_exhaustive]pub struct ReadOnly {
pub return_read_timestamp: bool,
pub timestamp_bound: Option<TimestampBound>,
/* private fields */
}Expand description
Message type to initiate a read-only transaction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.return_read_timestamp: boolIf true, the Cloud Spanner-selected read timestamp is included in the Transaction message that describes the transaction.
timestamp_bound: Option<TimestampBound>How to choose the timestamp for the read-only transaction.
Implementations
Sourceimpl ReadOnly
impl ReadOnly
Sourcepub fn set_return_read_timestamp<T: Into<bool>>(self, v: T) -> Self
pub fn set_return_read_timestamp<T: Into<bool>>(self, v: T) -> Self
Sets the value of return_read_timestamp.
Sourcepub fn set_timestamp_bound<T: Into<Option<TimestampBound>>>(self, v: T) -> Self
pub fn set_timestamp_bound<T: Into<Option<TimestampBound>>>(self, v: T) -> Self
Sets the value of timestamp_bound.
Note that all the setters affecting timestamp_bound are mutually
exclusive.
Sourcepub fn strong(&self) -> Option<&bool>
pub fn strong(&self) -> Option<&bool>
The value of timestamp_bound
if it holds a Strong, None if the field is not set or
holds a different branch.
Sourcepub fn set_strong<T: Into<bool>>(self, v: T) -> Self
pub fn set_strong<T: Into<bool>>(self, v: T) -> Self
Sets the value of timestamp_bound
to hold a Strong.
Note that all the setters affecting timestamp_bound are
mutually exclusive.
Sourcepub fn min_read_timestamp(&self) -> Option<&Box<Timestamp>>
pub fn min_read_timestamp(&self) -> Option<&Box<Timestamp>>
The value of timestamp_bound
if it holds a MinReadTimestamp, None if the field is not set or
holds a different branch.
Sourcepub fn set_min_read_timestamp<T: Into<Box<Timestamp>>>(self, v: T) -> Self
pub fn set_min_read_timestamp<T: Into<Box<Timestamp>>>(self, v: T) -> Self
Sets the value of timestamp_bound
to hold a MinReadTimestamp.
Note that all the setters affecting timestamp_bound are
mutually exclusive.
Sourcepub fn max_staleness(&self) -> Option<&Box<Duration>>
pub fn max_staleness(&self) -> Option<&Box<Duration>>
The value of timestamp_bound
if it holds a MaxStaleness, None if the field is not set or
holds a different branch.
Sourcepub fn set_max_staleness<T: Into<Box<Duration>>>(self, v: T) -> Self
pub fn set_max_staleness<T: Into<Box<Duration>>>(self, v: T) -> Self
Sets the value of timestamp_bound
to hold a MaxStaleness.
Note that all the setters affecting timestamp_bound are
mutually exclusive.
Sourcepub fn read_timestamp(&self) -> Option<&Box<Timestamp>>
pub fn read_timestamp(&self) -> Option<&Box<Timestamp>>
The value of timestamp_bound
if it holds a ReadTimestamp, None if the field is not set or
holds a different branch.
Sourcepub fn set_read_timestamp<T: Into<Box<Timestamp>>>(self, v: T) -> Self
pub fn set_read_timestamp<T: Into<Box<Timestamp>>>(self, v: T) -> Self
Sets the value of timestamp_bound
to hold a ReadTimestamp.
Note that all the setters affecting timestamp_bound are
mutually exclusive.
Sourcepub fn exact_staleness(&self) -> Option<&Box<Duration>>
pub fn exact_staleness(&self) -> Option<&Box<Duration>>
The value of timestamp_bound
if it holds a ExactStaleness, None if the field is not set or
holds a different branch.
Sourcepub fn set_exact_staleness<T: Into<Box<Duration>>>(self, v: T) -> Self
pub fn set_exact_staleness<T: Into<Box<Duration>>>(self, v: T) -> Self
Sets the value of timestamp_bound
to hold a ExactStaleness.
Note that all the setters affecting timestamp_bound are
mutually exclusive.