#[non_exhaustive]pub struct ReadWrite {
pub read_lock_mode: ReadLockMode,
pub multiplexed_session_previous_transaction_id: Bytes,
/* private fields */
}Expand description
Message type to initiate a read-write transaction. Currently this transaction type has no options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_lock_mode: ReadLockModeRead lock mode for the transaction.
multiplexed_session_previous_transaction_id: BytesOptional. Clients should pass the transaction ID of the previous transaction attempt that was aborted if this transaction is being executed on a multiplexed session.
Implementations
Sourceimpl ReadWrite
impl ReadWrite
Sourcepub fn set_read_lock_mode<T: Into<ReadLockMode>>(self, v: T) -> Self
pub fn set_read_lock_mode<T: Into<ReadLockMode>>(self, v: T) -> Self
Sets the value of read_lock_mode.
Sourcepub fn set_multiplexed_session_previous_transaction_id<T: Into<Bytes>>(
self,
v: T,
) -> Self
pub fn set_multiplexed_session_previous_transaction_id<T: Into<Bytes>>( self, v: T, ) -> Self
Sets the value of multiplexed_session_previous_transaction_id.