#[non_exhaustive]pub enum Selector {
SingleUse(Box<TransactionOptions>),
Id(Bytes),
Begin(Box<TransactionOptions>),
}Expand description
If no fields are set, the default is a single use transaction with strong concurrency.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SingleUse(Box<TransactionOptions>)
Execute the read or SQL query in a temporary transaction. This is the most efficient way to execute a transaction that consists of a single SQL query.
Id(Bytes)
Execute the read or SQL query in a previously-started transaction.
Begin(Box<TransactionOptions>)
Begin a new transaction and execute this read or SQL query in it. The transaction ID of the new transaction is returned in ResultSetMetadata.transaction, which is a Transaction.
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn from_single_use(value: impl Into<Box<TransactionOptions>>) -> Self
pub fn from_single_use(value: impl Into<Box<TransactionOptions>>) -> Self
Initializes the enum to the SingleUse branch.
Sourcepub fn from_begin(value: impl Into<Box<TransactionOptions>>) -> Self
pub fn from_begin(value: impl Into<Box<TransactionOptions>>) -> Self
Initializes the enum to the Begin branch.