Module mutation

Module mutation 

Write mutations and transaction commit binders.

Structs

Mutation
Represents an individual table modification to be applied to Cloud Spanner.
MutationGroup
A group of mutations that are applied atomically in a crate::batch::BatchWriteTransaction.
ValueBinder
A binder that associates a column name with a value within a WriteBuilder.
WriteBuilder
A builder for constructing Write mutations fluently.