pub struct Mutation { /* private fields */ }Expand description
Represents an individual table modification to be applied to Cloud Spanner.
Example
use google_cloud_spanner::mutation::Mutation;
let mutation = Mutation::new_insert_builder("Users")
.set("UserId").to(&1)
.set("UserName").to(&"Alice")
.build();Use the methods on Mutation to create a builder for the desired operation type.
Implementations
Sourceimpl Mutation
impl Mutation
Sourcepub fn new_insert_builder(table: impl Into<String>) -> WriteBuilder
pub fn new_insert_builder(table: impl Into<String>) -> WriteBuilder
Returns a builder that can be used to construct an Insert mutation against table.
Example
use google_cloud_spanner::mutation::Mutation;
let mutation = Mutation::new_insert_builder("Users")
.set("UserId").to(&1)
.build();Sourcepub fn new_update_builder(table: impl Into<String>) -> WriteBuilder
pub fn new_update_builder(table: impl Into<String>) -> WriteBuilder
Returns a builder that can be used to construct an Update mutation against table.
Example
use google_cloud_spanner::mutation::Mutation;
let mutation = Mutation::new_update_builder("Users")
.set("UserId").to(&1)
.set("UserName").to(&"Bob")
.build();Sourcepub fn new_insert_or_update_builder(table: impl Into<String>) -> WriteBuilder
pub fn new_insert_or_update_builder(table: impl Into<String>) -> WriteBuilder
Returns a builder that can be used to construct an InsertOrUpdate mutation against table.
Example
use google_cloud_spanner::mutation::Mutation;
let mutation = Mutation::new_insert_or_update_builder("Users")
.set("UserId").to(&1)
.set("UserName").to(&"Bob")
.build();Sourcepub fn new_replace_builder(table: impl Into<String>) -> WriteBuilder
pub fn new_replace_builder(table: impl Into<String>) -> WriteBuilder
Returns a builder that can be used to construct a Replace mutation against table.
Example
use google_cloud_spanner::mutation::Mutation;
let mutation = Mutation::new_replace_builder("Users")
.set("UserId").to(&1)
.set("UserName").to(&"Bob")
.build();Trait Implementations
impl StructuralPartialEq for Mutation