pub struct ReadRequest { /* private fields */ }Expand description
Represents a configured read request ready for execution.
Contains the table, optional index, keys, and columns. Allows configuring optional parameters on the read operation, such as a limit.
Implementations
Sourceimpl ReadRequest
impl ReadRequest
Sourcepub fn builder(
table: impl Into<String>,
columns: impl IntoIterator<Item = impl Into<String>>,
) -> ReadRequestBuilder
pub fn builder( table: impl Into<String>, columns: impl IntoIterator<Item = impl Into<String>>, ) -> ReadRequestBuilder
Creates a new read operation builder for a specific table.
Example
let builder = ReadRequest::builder("Users", vec!["Id", "Name"]);The table name and columns to retrieve are required to initiate a read.