ReadRequestBuilder

Struct ReadRequestBuilder 

pub struct ReadRequestBuilder { /* private fields */ }
Represents an incomplete read operation that requires specifying keys.

Example

// Read all rows from a table using its primary key.
let read_all = ReadRequest::builder("Users", vec!["Id", "Name"])
    .with_keys(KeySet::all())
    .build();

// Read specific rows using an index.
let read_by_id = ReadRequest::builder("Users", vec!["Id", "Name"])
    .with_index("UsersByIndex", key![1_i64])
    .set_limit(10)
    .build();

Use ReadRequest::builder to define the table and columns to be read. Keys must be supplied using with_keys (for the primary key) or with_index (for an index) to obtain an executable ReadRequest.

Implementations

Source

impl ReadRequestBuilder

pub fn with_keys(self, keys: impl Into<KeySet>) -> ConfiguredReadRequestBuilder

Supplies the KeySet targeting the table’s primary key.

Example
let request = ReadRequest::builder("Users", vec!["Id", "Name"]).with_keys(KeySet::all());

The keys parameter identifies the rows to be yielded by naming the primary keys of the rows in the table. Rows are yielded in table primary key order.

pub fn with_index( self, index: impl Into<String>, keys: impl Into<KeySet>, ) -> ConfiguredReadRequestBuilder

Supplies an index name and its associated KeySet.

Example
let request = ReadRequest::builder("Users", vec!["Id", "Name"]).with_index("UsersByIndex", key![1_i64]);

The keys parameter identifies the rows to be yielded by naming the index keys in the provided index. Rows are yielded in index key order.