ResultSet

Struct ResultSet 

pub struct ResultSet { /* private fields */ }
ResultSet contains the rows of a query result.

Example

while let Some(row) = rs.next().await {
    let row: Row = row?;
    // Process the row
}

Implementations

Source

impl ResultSet

pub fn metadata(&self) -> Option<&ResultSetMetadata>

Returns the metadata of the result set.

Example
if let Some(metadata) = rs.metadata() {
    for column in metadata.column_names() {
        println!("Column name: {}", column);
    }
}
pub fn stats(&self) -> Option<&ResultSetStats>

Returns the stats of the result set, if available.

Example
while let Some(row) = rs.next().await {
    let row = row?;
    // Process row
}
if let Some(stats) = rs.stats() {
    println!("Query plan: {:?}", stats.query_plan);
}

Stats are only available after the results have been fully consumed and the query was run in PLAN or PROFILE mode.

pub fn update_count(&self) -> Option<i64>

Returns the number of rows modified by the DML statement, if available.

Example
let runner = db_client.read_write_transaction().build().await?;
runner.run(async |tx| {
    let stmt = Statement::builder("UPDATE Singers SET LastName = 'Simpson' WHERE SingerId = @id THEN RETURN SingerId, LastName")
        .add_param("id", &123_i64)
        .build();
    let mut rs = tx.execute_query(stmt).await?;
    while let Some(row) = rs.next().await.transpose()? {
        // Process returned rows
    }
    if let Some(count) = rs.update_count() {
        println!("Rows modified: {}", count);
    }
    Ok(())
}).await?;

Returns the number of rows modified when this ResultSet was produced from a DML statement with a THEN RETURN clause.

pub async fn next(&mut self) -> Option<Result<Row>>

Fetches the next row from the result set.

Example
if let Some(row) = rs.next().await.transpose()? {
    // Process the row
}

Returns None when all rows have been retrieved.