ResultSetMetadata

Struct ResultSetMetadata 

pub struct ResultSetMetadata { /* private fields */ }
Metadata about a ResultSet.

Example

let client = Spanner::builder().build().await?;
let db = client.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db.single_use().build();
let mut rs = tx.execute_query(Statement::builder("SELECT 1 AS Number").build()).await?;

let metadata = rs.metadata().expect("metadata available");

for (name, type_) in metadata.column_names().iter().zip(metadata.column_types().iter()) {
    println!("Column: {} has type: {:?}", name, type_.code());
}

Implementations

Source

impl ResultSetMetadata

pub fn column_names(&self) -> &[String]

Returns the names of the columns in the result set.

pub fn column_types(&self) -> &[Type]

Returns the types of the columns in the result set.

pub fn undeclared_parameters(&self) -> &BTreeMap<String, Type>

Returns the types of the undeclared parameters in the result set.