pub struct Statement { /* private fields */ }Expand description
A SQL statement for execution on Spanner.
Example
let client = Spanner::builder().build().await.unwrap();
let db = client.database_client("projects/p/instances/i/databases/d").build().await.unwrap();
let tx = db.single_use().build();
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let mut rs = tx.execute_query(stmt).await?;
while let Some(row) = rs.next().await {
let row = row?;
// process row
}Implementations
Sourceimpl Statement
impl Statement
Sourcepub fn builder(sql: impl Into<String>) -> StatementBuilder
pub fn builder(sql: impl Into<String>) -> StatementBuilder
Creates a new statement builder.
Sourcepub fn set_query_mode(self, mode: QueryMode) -> Self
pub fn set_query_mode(self, mode: QueryMode) -> Self
Sets the query mode to use for this statement.
Example
let statement = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let mut query_plan = tx.execute_query(statement.clone().set_query_mode(QueryMode::Plan)).await?;This method consumes the statement and returns a new one with the specified mode.