StatementBuilder

Struct StatementBuilder 

pub struct StatementBuilder { /* private fields */ }
A builder for Statement.

Example

let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
    .add_param("id", &42)
    .build();

Implementations

Source

impl StatementBuilder

pub fn add_param<T: ToValue + ?Sized>( self, name: impl Into<String>, value: &T, ) -> Self

Adds a parameter value to this Statement.

The parameter value is sent without an explicit type code to Spanner. This allows Spanner to automatically infer the correct data type from the SQL string of the statement. It is recommended to use untyped parameter values, unless you explicitly want Spanner to verify that the type of the parameter value is exactly the same as the type that would otherwise be inferred from the SQL string.

pub fn add_typed_param<T: ToValue + ?Sized>( self, name: impl Into<String>, value: &T, param_type: Type, ) -> Self

Adds a typed parameter value to this Statement.

The parameter value is sent with an explicit type code to Spanner. The type code must correspond with the expression in the SQL string that the query parameter is bound to.

pub fn set_request_tag(self, tag: impl Into<String>) -> Self

Sets the request tag to use for this statement.

Example
let statement = Statement::builder("SELECT * FROM users")
    .set_request_tag("my-tag")
    .build();

See also: Troubleshooting with tags

pub fn set_priority(self, priority: Priority) -> Self

Sets the RPC priority to use for this statement.

Example
let statement = Statement::builder("SELECT * FROM users")
    .set_priority(Priority::Low)
    .build();
pub fn set_directed_read_options(self, options: DirectedReadOptions) -> Self

Sets the directed read options for this statement.

let dro = DirectedReadOptions::default();
let stmt = Statement::builder("SELECT * FROM users")
    .set_directed_read_options(dro)
    .build();

DirectedReadOptions can only be specified for a read-only transaction, otherwise Spanner returns an INVALID_ARGUMENT error.

pub fn set_query_options(self, options: QueryOptions) -> Self

Sets the query options to use for this statement.

Example
let options = QueryOptions::default()
    .set_optimizer_version("latest");
let statement = Statement::builder("SELECT * FROM users")
    .set_query_options(options)
    .build();
pub fn set_query_mode(self, mode: QueryMode) -> Self

Sets the query mode to use for this statement.

Example
let statement = Statement::builder("SELECT * FROM users")
    .set_query_mode(QueryMode::Plan)
    .build();
pub fn with_attempt_timeout(self, timeout: Duration) -> Self

Sets the per-attempt timeout for this statement.

pub fn with_retry_policy(self, policy: impl Into<RetryPolicyArg>) -> Self

Sets the retry policy for this statement.

pub fn with_backoff_policy(self, policy: impl Into<BackoffPolicyArg>) -> Self

Sets the backoff policy for this statement.

pub fn build(self) -> Statement

Builds and returns the finalized Statement object.