Module transaction

Module transaction 

Transaction-scoped interfaces and transaction runners. Re-exports for Spanner transactions.

Structs

BasicTransactionRetryPolicy
Policy for automatically retrying a transaction when it is aborted based on the number of attempts and total elapsed time.
MultiUseReadOnlyTransaction
A multi-use read-only transaction. This transaction can be used for multiple read queries ensuring consistency across all queries.
PartitionedDmlTransaction
A Partitioned DML transaction.
ReadWriteTransaction
A read-write transaction.
SingleUseReadOnlyTransaction
A single-use read-only transaction. A single-use read-only transaction is the most efficient way to execute a single query or read operation.
TimestampBound
Use a timestamp bound to specify how to choose a timestamp at which a query should read data.
TransactionRunner
A runner for read/write transactions. Aborted transactions are automatically retried.
WriteOnlyTransaction
A write-only transaction.

Enums

BeginTransactionOption
Options for how to start a transaction.