#[non_exhaustive]pub enum BeginTransactionOption {
InlineBegin,
ExplicitBegin,
}Expand description
Options for how to start a transaction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InlineBegin
The transaction will be started inlined with the first statement. This reduces the number of round-trips to Spanner by one.
ExplicitBegin
The transaction will be started explicitly using a BeginTransaction RPC.