pub struct BasicTransactionRetryPolicy { /* private fields */ }Expand description
Policy for automatically retrying a transaction when it is aborted based on the number of attempts and total elapsed time.
Implementations
Sourceimpl BasicTransactionRetryPolicy
impl BasicTransactionRetryPolicy
Sourcepub fn with_max_attempts(self, max_attempts: u32) -> Self
pub fn with_max_attempts(self, max_attempts: u32) -> Self
Sets the maximum number of attempts to make.
Sourcepub fn with_total_timeout(self, total_timeout: Duration) -> Self
pub fn with_total_timeout(self, total_timeout: Duration) -> Self
Sets the total maximum time to spend retrying.
Sourcepub fn max_attempts(&self) -> u32
pub fn max_attempts(&self) -> u32
Returns the maximum number of attempts configured.
Sourcepub fn total_timeout(&self) -> Duration
pub fn total_timeout(&self) -> Duration
Returns the total maximum time configured.