MultiUseReadOnlyTransaction

Struct MultiUseReadOnlyTransaction 

pub struct MultiUseReadOnlyTransaction { /* private fields */ }
A multi-use read-only transaction. This transaction can be used for multiple read queries ensuring consistency across all queries.

Example

let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db_client.read_only_transaction().build().await?;
let stmt1 = Statement::builder("SELECT * FROM users WHERE id = @id")
    .add_param("id", &42)
    .build();
let mut rs1 = tx.execute_query(stmt1).await?;

let stmt2 = Statement::builder("SELECT * FROM other_table")
    .build();
let mut rs2 = tx.execute_query(stmt2).await?;

Implementations

Source

impl MultiUseReadOnlyTransaction

pub fn read_timestamp(&self) -> Option<Timestamp>

Returns the read timestamp chosen for the transaction.

pub async fn execute_query<T: Into<Statement>>( &self, statement: T, ) -> Result<ResultSet>

Executes a query using this transaction.

Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db_client.read_only_transaction().build().await?;
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
    .add_param("id", &42)
    .build();
let mut rs = tx.execute_query(stmt).await?;
while let Some(row) = rs.next().await {
    let _row = row?;
    // process row
}
pub async fn execute_read<T: Into<ReadRequest>>( &self, read: T, ) -> Result<ResultSet>

Reads rows from the database using key lookups and scans, as a simple key/value style alternative to execute_query.

Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.read_only_transaction().build().await?;

// Read using the primary key
let read_by_pk = ReadRequest::builder("Users", vec!["Id", "Name"]).with_keys(KeySet::all()).build();
let mut result_set = transaction.execute_read(read_by_pk).await?;
while let Some(row) = result_set.next().await {
    let _row = row?;
    // process row
}

// Read using a secondary index
let read_by_index = ReadRequest::builder("Users", vec!["Id", "Name"])
    .with_index("UsersByIndex", key![1_i64]).build();
let mut result_set = transaction.execute_read(read_by_index).await?;
while let Some(row) = result_set.next().await {
    let _row = row?;
    // process row
}