pub struct SingleUseReadOnlyTransaction { /* private fields */ }Expand description
A single-use read-only transaction. A single-use read-only transaction is the most efficient way to execute a single query or read operation.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db_client.single_use().build();
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let rs = tx.execute_query(stmt).await?;Implementations
Sourceimpl SingleUseReadOnlyTransaction
impl SingleUseReadOnlyTransaction
Sourcepub async fn execute_query<T: Into<Statement>>(
&self,
statement: T,
) -> Result<ResultSet>
pub async fn execute_query<T: Into<Statement>>( &self, statement: T, ) -> Result<ResultSet>
Executes a query.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let tx = db_client.single_use().build();
let stmt = Statement::builder("SELECT * FROM users WHERE id = @id")
.add_param("id", &42)
.build();
let mut rs = tx.execute_query(stmt).await?;
while let Some(row) = rs.next().await {
let _row = row?;
// process row
}Sourcepub async fn execute_read<T: Into<ReadRequest>>(
&self,
read: T,
) -> Result<ResultSet>
pub async fn execute_read<T: Into<ReadRequest>>( &self, read: T, ) -> Result<ResultSet>
Reads rows from the database using key lookups and scans, as a simple key/value style alternative to execute_query.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.single_use().build();
// Read using the primary key
let read_by_pk = ReadRequest::builder("Users", vec!["Id", "Name"]).with_keys(KeySet::all()).build();
let mut result_set = transaction.execute_read(read_by_pk).await?;
while let Some(row) = result_set.next().await {
let _row = row?;
// process row
}
// Read using a secondary index
let read_by_index = ReadRequest::builder("Users", vec!["Id", "Name"])
.with_index("UsersByIndex", key![1_i64]).build();
let mut result_set = transaction.execute_read(read_by_index).await?;
while let Some(row) = result_set.next().await {
let _row = row?;
// process row
}Trait Implementations