pub struct TimestampBound(/* private fields */);Expand description
Use a timestamp bound to specify how to choose a timestamp at which a query should read data.
Example
let client = Spanner::builder().build().await.unwrap();
let db = client.database_client("projects/p/instances/i/databases/d").build().await.unwrap();
let tx = db.single_use().set_timestamp_bound(TimestampBound::strong()).build();See https://cloud.google.com/spanner/docs/timestamp-bounds for more information.
Implementations
Sourceimpl TimestampBound
impl TimestampBound
Sourcepub fn strong() -> Self
pub fn strong() -> Self
Returns a strong timestamp bound. Strong reads are guaranteed to see the effects of all transactions that have committed before the start of the read.
See timestamp_bound_strong for more information.
Sourcepub fn read_timestamp<T>(timestamp: T) -> Self
pub fn read_timestamp<T>(timestamp: T) -> Self
Returns a timestamp bound for an exact timestamp. The data will be read as it was at the given timestamp.
See timestamp_bound_exact_staleness for more information.
Sourcepub fn try_read_timestamp<T>(timestamp: T) -> Result<Self, T::Error>
pub fn try_read_timestamp<T>(timestamp: T) -> Result<Self, T::Error>
Returns a timestamp bound for an exact timestamp, returning an error if the timestamp is out of range.
See timestamp_bound_exact_staleness for more information.
Sourcepub fn min_read_timestamp<T>(timestamp: T) -> Self
pub fn min_read_timestamp<T>(timestamp: T) -> Self
Returns a timestamp bound for a minimum read timestamp. The data will be read as it was at the given timestamp or later.
See timestamp_bound_bounded_staleness for more information.
Sourcepub fn try_min_read_timestamp<T>(timestamp: T) -> Result<Self, T::Error>
pub fn try_min_read_timestamp<T>(timestamp: T) -> Result<Self, T::Error>
Returns a timestamp bound for a minimum read timestamp, returning an error if the timestamp is out of range.
See timestamp_bound_bounded_staleness for more information.
Sourcepub fn exact_staleness<T>(duration: T) -> Self
pub fn exact_staleness<T>(duration: T) -> Self
Returns a timestamp bound for an exact staleness. The data will be read as it was at the given timestamp calculated by the current server time minus the given duration.
See timestamp_bound_exact_staleness for more information.
Sourcepub fn try_exact_staleness<T>(duration: T) -> Result<Self, T::Error>
pub fn try_exact_staleness<T>(duration: T) -> Result<Self, T::Error>
Returns a timestamp bound for an exact staleness, returning an error if the duration is out of range.
See timestamp_bound_exact_staleness for more information.
Sourcepub fn max_staleness<T>(duration: T) -> Self
pub fn max_staleness<T>(duration: T) -> Self
Returns a timestamp bound for a maximum staleness. The data will be read as it was at the current server time minus the given duration or later.
See timestamp_bound_bounded_staleness for more information.
Sourcepub fn try_max_staleness<T>(duration: T) -> Result<Self, T::Error>
pub fn try_max_staleness<T>(duration: T) -> Result<Self, T::Error>
Returns a timestamp bound for a maximum staleness, returning an error if the duration is out of range.
See timestamp_bound_bounded_staleness for more information.