TransactionRunner

Struct TransactionRunner 

pub struct TransactionRunner { /* private fields */ }
A runner for read/write transactions. Aborted transactions are automatically retried.

Implementations

Source

impl TransactionRunner

pub async fn run<T, F>(self, work: F) -> Result<TransactionResult<T>>

Runs the provided closure within the context of a read/write transaction.

Example
let db_client = client.database_client("projects/p/instances/i/databases/d").build().await?;
let runner = db_client.read_write_transaction().build().await?;

let result = runner.run(async |transaction| {
    let statement = Statement::builder("UPDATE MyTable SET MyColumn = 'MyValue' WHERE Id = 1").build();
    transaction.execute_update(statement).await?;
    Ok(42)
}).await?;

If the transaction is aborted by Spanner, the closure will be retried automatically according to the configured TransactionRetryPolicy.

The transaction is automatically committed if the closure returns Ok. If the closure returns Err, the transaction will be rolled back and the error will be propagated.