Type and value representations and conversion traits.
Re-exports
Structs
- List
- A lightweight wrapper around a protobuf ListValue.
- Struct
- A lightweight wrapper around a protobuf Struct.
- Value
- Value is a transparent wrapper around a protobuf value. It adds helper methods for accessing the underlying value.
Enums
- Kind
- Kind indicates the type of the value.