pub enum Kind {
Null,
Number,
String,
Bool,
Struct,
List,
}Expand description
Kind indicates the type of the value.
This enum maps 1-to-1 with the frozen specification of JSON/Protobuf types
in google.protobuf.Value, and is guaranteed not to grow.
Variants
Null
Represents a null value of any data type.
Number
Represents a floating point value.
String
Represents a UTF-8 string value or encoded representations of other data types, such as base64-encoded bytes, decimals, dates, timestamps, and integers.
Bool
Represents a boolean value.
Struct
Represents a structured object containing a collection of key-value pairs.
List
Represents an ordered list of values.