pub struct Value(/* private fields */);Expand description
Value is a transparent wrapper around a protobuf value. It adds helper methods for accessing the underlying value.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn try_as_string(&self) -> Option<&str>
pub fn try_as_string(&self) -> Option<&str>
Returns the underlying string value if the kind is String.
Sourcepub fn as_string(&self) -> &str
pub fn as_string(&self) -> &str
Returns the underlying string value. Panics if the kind is not String.
Sourcepub fn try_as_bool(&self) -> Option<bool>
pub fn try_as_bool(&self) -> Option<bool>
Returns the underlying bool value if the kind is Bool.
Sourcepub fn as_bool(&self) -> bool
pub fn as_bool(&self) -> bool
Returns the underlying bool value. Panics if the kind is not Bool.
Sourcepub fn try_as_f64(&self) -> Option<f64>
pub fn try_as_f64(&self) -> Option<f64>
Returns the underlying number value if the kind is Number.
Sourcepub fn as_f64(&self) -> f64
pub fn as_f64(&self) -> f64
Returns the underlying number value. Panics if the kind is not Number.
Sourcepub fn try_as_struct(&self) -> Option<&Struct>
pub fn try_as_struct(&self) -> Option<&Struct>
Returns the underlying struct value as a map of Values if the kind is Struct.
Sourcepub fn as_struct(&self) -> &Struct
pub fn as_struct(&self) -> &Struct
Returns the underlying struct value. Panics if the kind is not Struct.
Sourcepub fn try_as_list(&self) -> Option<&List>
pub fn try_as_list(&self) -> Option<&List>
Returns the underlying list value as a vector of Values if the kind is List.