Google Cloud Client Libraries for Rust - Spanner
WARNING: this is a preview release of the crate. We believe the APIs to be stable. We also are seeking feedback about the APIs and may need to make breaking changes if we discover that some parts are hard to use.
We welcome feedback about the APIs, documentation, missing features, bugs, etc.
Modules
- batch
- Batch execution and query partitioning support. Re-exports for Spanner batch execution and query partitioning.
- builder
- Consolidates all client and request builders. Re-exports for Spanner client and request builders.
- client
- Spanner client implementations.
- error
- Crate error types.
- key
- Key and key range definition types.
- model
- The messages and enums that are part of this client library.
- mutation
- Write mutations and transaction commit binders.
- read
- Configurable read requests and builders.
- result
- Spanner execution result streams and rows. Public types for Spanner execution results.
- statement
- SQL statement builders and parameter bindings.
- stub
- Mocking and stub definitions.
- transaction
- Transaction-scoped interfaces and transaction runners. Re-exports for Spanner transactions.
- value
- Type and value representations and conversion traits.
Macros
- key
- Represents a primary key or index key for Cloud Spanner.
Structs
- Decimal
Decimalrepresents a 128 bit representation of a fixed-precision decimal number. The finite set of values of typeDecimalare of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.- Error
- The core error returned by all client libraries.
Type Aliases
- Result
- An alias of std::result::Result where the error is always Error.