Batch execution and query partitioning support. Re-exports for Spanner batch execution and query partitioning.
Structs
- Batch
Dml - A batch of DML statements to be executed in a single round-trip to Spanner.
- Batch
Read Only Transaction - A read-only transaction that can be used to partition reads and queries and execute these in parallel across multiple workers.
- Batch
Write Response Stream - A stream of BatchWriteResponse messages.
- Batch
Write Transaction - A transaction for executing batch writes.
- Partition
- Defines the segments of data to be read in a partitioned read or query. These partitions can be serialized and processed across several different machines or processes.