Crate error types.
Structs
- Batch
Update Error - An error that occurs when an
execute_batch_updatepartially succeeds.
Enums
- Convert
Error - Represent failures in converting a Spanner Value to a Rust type.
- Duration
Error - Represent failures in converting or creating Duration instances.
- Spanner
Internal Error - An unexpected error that occurs when the client receives data from Spanner that it cannot properly parse or handle. This typically indicates a bug in the client library or the Spanner service itself, though other causes are possible.
- Timestamp
Error - Represent failures in converting or creating Timestamp instances.