#[non_exhaustive]pub enum SpannerInternalError {
UnexpectedData(String),
}Expand description
An unexpected error that occurs when the client receives data from Spanner that it cannot properly parse or handle. This typically indicates a bug in the client library or the Spanner service itself, though other causes are possible.
Troubleshooting
This indicates a bug in the client, the service, or a message corrupted while in transit. Please open an issue with as much detail as possible.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedData(String)
Indicates that Spanner returned data in an unexpected or unparsable format.
This represents an unexpected state and is an indication of an internal bug.