macro_rules! key {
($($val:expr),* $(,)?) => { ... };
}Expand description
Represents a primary key or index key for Cloud Spanner.
Example
use google_cloud_spanner::key;
let key = key![1_i64, "Alice"];Keys are constructed by appending values in the correct column order.