The messages and enums that are part of this client library.
Modules
- batch_
write_ request - Defines additional types related to BatchWriteRequest.
- change_
stream_ record - Defines additional types related to ChangeStreamRecord.
- commit_
request - Defines additional types related to CommitRequest.
- commit_
response - Defines additional types related to CommitResponse.
- directed_
read_ options - Defines additional types related to DirectedReadOptions.
- execute_
batch_ dml_ request - Defines additional types related to ExecuteBatchDmlRequest.
- execute_
sql_ request - Defines additional types related to ExecuteSqlRequest.
- key_
range - Defines additional types related to KeyRange.
- key_
recipe - Defines additional types related to KeyRecipe.
- mutation
- Defines additional types related to Mutation.
- plan_
node - Defines additional types related to PlanNode.
- query_
advisor_ result - Defines additional types related to QueryAdvisorResult.
- read_
request - Defines additional types related to ReadRequest.
- request_
options - Defines additional types related to RequestOptions.
- result_
set_ stats - Defines additional types related to ResultSetStats.
- routing_
hint - Defines additional types related to RoutingHint.
- struct_
type - Defines additional types related to StructType.
- tablet
- Defines additional types related to Tablet.
- transaction_
options - Defines additional types related to TransactionOptions.
- transaction_
selector - Defines additional types related to TransactionSelector.
Structs
- Batch
Create Sessions Request - The request for BatchCreateSessions.
- Batch
Create Sessions Response - The response for BatchCreateSessions.
- Batch
Write Request - The request for [BatchWrite][google.spanner.v1.Spanner.BatchWrite].
- Batch
Write Response - The result of applying a batch of mutations.
- Begin
Transaction Request - The request for BeginTransaction.
- Cache
Update - A
CacheUpdateexpresses a set of changes the client should incorporate into its location cache. These changes may or may not be newer than what the client has in its cache, and should be discarded if necessary.CacheUpdates can be obtained in response to requests that included aRoutingHintfield, but may also be obtained by explicit location-fetching RPCs which may be added in the future. - Change
Stream Record - Spanner Change Streams enable customers to capture and stream out changes to their Spanner databases in real-time. A change stream can be created with option partition_mode=‘IMMUTABLE_KEY_RANGE’ or partition_mode=‘MUTABLE_KEY_RANGE’.
- Commit
Request - The request for Commit.
- Commit
Response - The response for Commit.
- Create
Session Request - The request for CreateSession.
- Delete
Session Request - The request for DeleteSession.
- Directed
Read Options - The
DirectedReadOptionscan be used to indicate which replicas or regions should be used for non-transactional reads or queries. - Execute
Batch DmlRequest - The request for ExecuteBatchDml.
- Execute
Batch DmlResponse - The response for ExecuteBatchDml. Contains a list of ResultSet messages, one for each DML statement that has successfully executed, in the same order as the statements in the request. If a statement fails, the status in the response body identifies the cause of the failure.
- Execute
SqlRequest - The request for ExecuteSql and [ExecuteStreamingSql][google.spanner.v1.Spanner.ExecuteStreamingSql].
- Fetch
Cache Update Request - The request for [FetchCacheUpdate][google.spanner.v1.Spanner.FetchCacheUpdate].
- GetSession
Request - The request for GetSession.
- Group
- A
Grouprepresents a paxos group in a database. A group is a set of tablets that are replicated across multiple servers. Groups may have a leader tablet. Groups store one (or sometimes more) ranges of keys. - KeyRange
- KeyRange represents a range of rows in a table or index.
- KeyRecipe
- A
KeyRecipeprovides the metadata required to translate reads, mutations, and queries into a byte array in “sortable string format” (ssformat)that can be used withRanges to route requests. Note that the client must tolerateKeyRecipes that appear to be invalid, since theKeyRecipeformat may change over time. Requests with invalidKeyRecipes should be routed to a default server. - KeySet
KeySetdefines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way.- List
Sessions Request - The request for ListSessions.
- List
Sessions Response - The response for ListSessions.
- Multiplexed
Session Precommit Token - When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
- Mutation
- A modification to one or more Cloud Spanner rows. Mutations can be applied to a Cloud Spanner database by sending them in a Commit call.
- Partial
Result Set - Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.
- Partition
- Information returned for each partition returned in a PartitionResponse.
- Partition
Options - Options for a
PartitionQueryRequestandPartitionReadRequest. - Partition
Query Request - The request for PartitionQuery
- Partition
Read Request - The request for PartitionRead
- Partition
Response - The response for PartitionQuery or PartitionRead
- Plan
Node - Node information for nodes appearing in a QueryPlan.plan_nodes.
- Query
Advisor Result - Output of query advisor analysis.
- Query
Plan - Contains an ordered list of nodes appearing in the query plan.
- Range
- A
Rangerepresents a range of keys in a database. The keys themselves are encoded in “sortable string format”, also known as ssformat. Consult Spanner’s open source client libraries for details on the encoding. - Read
Request - The request for Read and [StreamingRead][google.spanner.v1.Spanner.StreamingRead].
- Recipe
List - A
RecipeListcontains a list ofKeyRecipes, which share the same schema generation. - Request
Options - Common request options for various APIs.
- Result
Set - Results from Read or ExecuteSql.
- Result
SetMetadata - Metadata about a ResultSet or PartialResultSet.
- Result
SetStats - Additional statistics about a ResultSet or PartialResultSet.
- Rollback
Request - The request for Rollback.
- Routing
Hint RoutingHintcan be optionally added to location-aware Spanner requests. It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.- Session
- A session in the Cloud Spanner API.
- Struct
Type StructTypedefines the fields of a STRUCT type.- Tablet
- A
Tabletrepresents a single replica of aGroup. A tablet is served by a single server at a time, and can move between servers due to server death or simply load balancing. - Transaction
- A transaction.
- Transaction
Options - Options to use for transactions.
- Transaction
Selector - This message is used to select the transaction in which a Read or ExecuteSql call runs.
- Type
Typeindicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query.
Enums
- Type
Annotation Code TypeAnnotationCodeis used as a part of Type to disambiguate SQL types that should be used for a given Cloud Spanner value. Disambiguation is needed because the same Cloud Spanner type can be mapped to different SQL types depending on SQL dialect. TypeAnnotationCode doesn’t affect the way value is serialized.- Type
Code TypeCodeis used as part of Type to indicate the type of a Cloud Spanner value.