#[non_exhaustive]pub struct QueryOptions {
pub optimizer_version: String,
pub optimizer_statistics_package: String,
/* private fields */
}Expand description
Query optimizer configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.optimizer_version: StringAn option to control the selection of optimizer version.
This parameter allows individual queries to pick different query optimizer versions.
Specifying latest as a value instructs Cloud Spanner to use the
latest supported query optimizer version. If not specified, Cloud Spanner
uses the optimizer version set at the database level options. Any other
positive integer (from the list of supported optimizer versions)
overrides the default optimizer version for query execution.
The list of supported optimizer versions can be queried from
SPANNER_SYS.SUPPORTED_OPTIMIZER_VERSIONS.
Executing a SQL statement with an invalid optimizer version fails with
an INVALID_ARGUMENT error.
See https://cloud.google.com/spanner/docs/query-optimizer/manage-query-optimizer for more information on managing the query optimizer.
The optimizer_version statement hint has precedence over this setting.
optimizer_statistics_package: StringAn option to control the selection of optimizer statistics package.
This parameter allows individual queries to use a different query optimizer statistics package.
Specifying latest as a value instructs Cloud Spanner to use the latest
generated statistics package. If not specified, Cloud Spanner uses
the statistics package set at the database level options, or the latest
package if the database option isn’t set.
The statistics package requested by the query has to be exempt from garbage collection. This can be achieved with the following DDL statement:
ALTER STATISTICS <package_name> SET OPTIONS (allow_gc=false)The list of available statistics packages can be queried from
INFORMATION_SCHEMA.SPANNER_STATISTICS.
Executing a SQL statement with an invalid optimizer statistics package
or with a statistics package that allows garbage collection fails with
an INVALID_ARGUMENT error.
Implementations
Sourceimpl QueryOptions
impl QueryOptions
Sourcepub fn set_optimizer_version<T: Into<String>>(self, v: T) -> Self
pub fn set_optimizer_version<T: Into<String>>(self, v: T) -> Self
Sets the value of optimizer_version.
Sourcepub fn set_optimizer_statistics_package<T: Into<String>>(self, v: T) -> Self
pub fn set_optimizer_statistics_package<T: Into<String>>(self, v: T) -> Self
Sets the value of optimizer_statistics_package.