Defines additional types related to KeyRecipe.
Modules
Structs
- Part
- An ssformat key is composed of a sequence of tag numbers and key column
values.
Partrepresents a single tag or key column value.
Enums
- Target
- A recipe can be associated with a table, index, or query. Tables recipes are used to encode read and write keys; index recipes are used for index reads, and query recipes are used only for SQL queries.