#[non_exhaustive]pub struct Part {
pub tag: u32,
pub order: Order,
pub null_order: NullOrder,
pub type: Option<Type>,
pub struct_identifiers: Vec<i32>,
pub value_type: Option<ValueType>,
/* private fields */
}Expand description
An ssformat key is composed of a sequence of tag numbers and key column
values. Part represents a single tag or key column value.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tag: u32If non-zero, tag is the only field present in this Part. The part
is encoded by appending tag to the ssformat key.
order: OrderWhether the key column is sorted ascending or descending. Only present
if tag is zero.
null_order: NullOrderHow NULLs are represented in the encoded key part. Only present if tag
is zero.
type: Option<Type>The type of the key part. Only present if tag is zero.
struct_identifiers: Vec<i32>It is a repeated field to support fetching key columns from nested
structs, such as STRUCT query parameters.
value_type: Option<ValueType>Only present if tag is zero.
Implementations
Sourceimpl Part
impl Part
Sourcepub fn set_null_order<T: Into<NullOrder>>(self, v: T) -> Self
pub fn set_null_order<T: Into<NullOrder>>(self, v: T) -> Self
Sets the value of null_order.
Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of r#type.
Sourcepub fn set_struct_identifiers<T, V>(self, v: T) -> Self
pub fn set_struct_identifiers<T, V>(self, v: T) -> Self
Sets the value of struct_identifiers.
Sourcepub fn set_value_type<T: Into<Option<ValueType>>>(self, v: T) -> Self
pub fn set_value_type<T: Into<Option<ValueType>>>(self, v: T) -> Self
Sets the value of value_type.
Note that all the setters affecting value_type are mutually
exclusive.
Sourcepub fn identifier(&self) -> Option<&String>
pub fn identifier(&self) -> Option<&String>
The value of value_type
if it holds a Identifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_identifier<T: Into<String>>(self, v: T) -> Self
pub fn set_identifier<T: Into<String>>(self, v: T) -> Self
Sets the value of value_type
to hold a Identifier.
Note that all the setters affecting value_type are
mutually exclusive.
Sourcepub fn value(&self) -> Option<&Box<Value>>
pub fn value(&self) -> Option<&Box<Value>>
The value of value_type
if it holds a Value, None if the field is not set or
holds a different branch.
Sourcepub fn set_value<T: Into<Box<Value>>>(self, v: T) -> Self
pub fn set_value<T: Into<Box<Value>>>(self, v: T) -> Self
Sets the value of value_type
to hold a Value.
Note that all the setters affecting value_type are
mutually exclusive.
Sourcepub fn random(&self) -> Option<&bool>
pub fn random(&self) -> Option<&bool>
The value of value_type
if it holds a Random, None if the field is not set or
holds a different branch.
Sourcepub fn set_random<T: Into<bool>>(self, v: T) -> Self
pub fn set_random<T: Into<bool>>(self, v: T) -> Self
Sets the value of value_type
to hold a Random.
Note that all the setters affecting value_type are
mutually exclusive.