#[non_exhaustive]pub enum Operation {
Insert(Box<Write>),
Update(Box<Write>),
InsertOrUpdate(Box<Write>),
Replace(Box<Write>),
Delete(Box<Delete>),
Send(Box<Send>),
Ack(Box<Ack>),
}Expand description
Required. The operation to perform.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Insert(Box<Write>)
Insert new rows in a table. If any of the rows already exist,
the write or transaction fails with error ALREADY_EXISTS.
Update(Box<Write>)
Update existing rows in a table. If any of the rows does not
already exist, the transaction fails with error NOT_FOUND.
InsertOrUpdate(Box<Write>)
Like insert, except that if the row already exists, then its column values are overwritten with the ones provided. Any column values not explicitly written are preserved.
When using
insert_or_update, just as
when using insert, all NOT NULL
columns in the table must be given a value. This holds true even when the
row already exists and will therefore actually be updated.
Replace(Box<Write>)
Like insert, except that if the row
already exists, it is deleted, and the column values provided are
inserted instead. Unlike
insert_or_update, this
means any values not explicitly written become NULL.
In an interleaved table, if you create the child table with the
ON DELETE CASCADE annotation, then replacing a parent row
also deletes the child rows. Otherwise, you must delete the
child rows before you replace the parent row.
Delete(Box<Delete>)
Delete rows from a table. Succeeds whether or not the named rows were present.
Send(Box<Send>)
Send a message to a queue.
Ack(Box<Ack>)
Ack a message from a queue.
Implementations
Sourceimpl Operation
impl Operation
Sourcepub fn from_insert(value: impl Into<Box<Write>>) -> Self
pub fn from_insert(value: impl Into<Box<Write>>) -> Self
Initializes the enum to the Insert branch.
Sourcepub fn from_update(value: impl Into<Box<Write>>) -> Self
pub fn from_update(value: impl Into<Box<Write>>) -> Self
Initializes the enum to the Update branch.
Sourcepub fn from_insert_or_update(value: impl Into<Box<Write>>) -> Self
pub fn from_insert_or_update(value: impl Into<Box<Write>>) -> Self
Initializes the enum to the InsertOrUpdate branch.
Sourcepub fn from_replace(value: impl Into<Box<Write>>) -> Self
pub fn from_replace(value: impl Into<Box<Write>>) -> Self
Initializes the enum to the Replace branch.