Delete

Struct Delete 

#[non_exhaustive]
pub struct Delete { pub table: String, pub key_set: Option<KeySet>, /* private fields */ }
Arguments to delete operations.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
table: String

Required. The table whose rows will be deleted.

key_set: Option<KeySet>

Required. The primary keys of the rows within table to delete. The primary keys must be specified in the order in which they appear in the PRIMARY KEY() clause of the table’s equivalent DDL statement (the DDL statement used to create the table). Delete is idempotent. The transaction will succeed even if some or all rows do not exist.

Implementations

Source

impl Delete

pub fn new() -> Self

Creates a new default instance.

pub fn set_table<T: Into<String>>(self, v: T) -> Self

Sets the value of table.

pub fn set_key_set<T>(self, v: T) -> Self
where T: Into<KeySet>,

Sets the value of key_set.

pub fn set_or_clear_key_set<T>(self, v: Option<T>) -> Self
where T: Into<KeySet>,

Sets or clears the value of key_set.