ChildLink

Struct ChildLink 

#[non_exhaustive]
pub struct ChildLink { pub child_index: i32, pub type: String, pub variable: String, /* private fields */ }
Metadata associated with a parent-child relationship appearing in a PlanNode.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
child_index: i32

The node to which the link points.

type: String

The type of the link. For example, in Hash Joins this could be used to distinguish between the build child and the probe child, or in the case of the child being an output variable, to represent the tag associated with the output variable.

variable: String

Only present if the child node is SCALAR and corresponds to an output variable of the parent node. The field carries the name of the output variable. For example, a TableScan operator that reads rows from a table will have child links to the SCALAR nodes representing the output variables created for each column that is read by the operator. The corresponding variable fields will be set to the variable names assigned to the columns.

Implementations

pub fn new() -> Self

Creates a new default instance.

pub fn set_child_index<T: Into<i32>>(self, v: T) -> Self

Sets the value of child_index.

pub fn set_type<T: Into<String>>(self, v: T) -> Self

Sets the value of r#type.

pub fn set_variable<T: Into<String>>(self, v: T) -> Self

Sets the value of variable.