#[non_exhaustive]pub struct BatchWriteRequest {
pub session: String,
pub request_options: Option<RequestOptions>,
pub mutation_groups: Vec<MutationGroup>,
pub exclude_txn_from_change_streams: bool,
/* private fields */
}Expand description
The request for [BatchWrite][google.spanner.v1.Spanner.BatchWrite].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session: StringRequired. The session in which the batch request is to be run.
request_options: Option<RequestOptions>Common options for this request.
mutation_groups: Vec<MutationGroup>Required. The groups of mutations to be applied.
exclude_txn_from_change_streams: boolOptional. If you don’t set the exclude_txn_from_change_streams option or
if it’s set to false, then any change streams monitoring columns modified
by transactions will capture the updates made within that transaction.
Implementations
Sourceimpl BatchWriteRequest
impl BatchWriteRequest
Sourcepub fn set_session<T: Into<String>>(self, v: T) -> Self
pub fn set_session<T: Into<String>>(self, v: T) -> Self
Sets the value of session.
Sourcepub fn set_request_options<T>(self, v: T) -> Selfwhere
T: Into<RequestOptions>,
pub fn set_request_options<T>(self, v: T) -> Selfwhere
T: Into<RequestOptions>,
Sets the value of request_options.
Sourcepub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<RequestOptions>,
pub fn set_or_clear_request_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<RequestOptions>,
Sets or clears the value of request_options.
Sourcepub fn set_mutation_groups<T, V>(self, v: T) -> Self
pub fn set_mutation_groups<T, V>(self, v: T) -> Self
Sets the value of mutation_groups.
Sourcepub fn set_exclude_txn_from_change_streams<T: Into<bool>>(self, v: T) -> Self
pub fn set_exclude_txn_from_change_streams<T: Into<bool>>(self, v: T) -> Self
Sets the value of exclude_txn_from_change_streams.