KeyRecipe

Struct KeyRecipe 

#[non_exhaustive]
pub struct KeyRecipe { pub part: Vec<Part>, pub target: Option<Target>, /* private fields */ }
A KeyRecipe provides the metadata required to translate reads, mutations, and queries into a byte array in “sortable string format” (ssformat)that can be used with Ranges to route requests. Note that the client must tolerate KeyRecipes that appear to be invalid, since the KeyRecipe format may change over time. Requests with invalid KeyRecipes should be routed to a default server.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
part: Vec<Part>

Parts are in the order they should appear in the encoded key.

target: Option<Target>

A recipe can be associated with a table, index, or query. Tables recipes are used to encode read and write keys; index recipes are used for index reads, and query recipes are used only for SQL queries.

Implementations

Source

impl KeyRecipe

pub fn new() -> Self

Creates a new default instance.

pub fn set_part<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Part>,

Sets the value of part.

pub fn set_target<T: Into<Option<Target>>>(self, v: T) -> Self

Sets the value of target.

Note that all the setters affecting target are mutually exclusive.

pub fn table_name(&self) -> Option<&String>

The value of target if it holds a TableName, None if the field is not set or holds a different branch.

pub fn set_table_name<T: Into<String>>(self, v: T) -> Self

Sets the value of target to hold a TableName.

Note that all the setters affecting target are mutually exclusive.

pub fn index_name(&self) -> Option<&String>

The value of target if it holds a IndexName, None if the field is not set or holds a different branch.

pub fn set_index_name<T: Into<String>>(self, v: T) -> Self

Sets the value of target to hold a IndexName.

Note that all the setters affecting target are mutually exclusive.

pub fn operation_uid(&self) -> Option<&u64>

The value of target if it holds a OperationUid, None if the field is not set or holds a different branch.

pub fn set_operation_uid<T: Into<u64>>(self, v: T) -> Self

Sets the value of target to hold a OperationUid.

Note that all the setters affecting target are mutually exclusive.