KeySet

Struct KeySet 

#[non_exhaustive]
pub struct KeySet { pub keys: Vec<ListValue>, pub ranges: Vec<KeyRange>, pub all: bool, /* private fields */ }
KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way.

If the same key is specified multiple times in the set (for example if two ranges, two keys, or a key and a range overlap), Cloud Spanner behaves as if the key were only specified once.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
keys: Vec<ListValue>

A list of specific keys. Entries in keys should have exactly as many elements as there are columns in the primary or index key with which this KeySet is used. Individual key values are encoded as described here.

ranges: Vec<KeyRange>

A list of key ranges. See KeyRange for more information about key range specifications.

all: bool

For convenience all can be set to true to indicate that this KeySet matches all keys in the table or index. Note that any keys specified in keys or ranges are only yielded once.

Implementations

Source

impl KeySet

pub fn new() -> Self

Creates a new default instance.

pub fn set_keys<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ListValue>,

Sets the value of keys.

pub fn set_ranges<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<KeyRange>,

Sets the value of ranges.

pub fn set_all<T: Into<bool>>(self, v: T) -> Self

Sets the value of all.