#[non_exhaustive]pub struct MultiplexedSessionPrecommitToken {
pub precommit_token: Bytes,
pub seq_num: i32,
/* private fields */
}Expand description
When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.precommit_token: BytesOpaque precommit token.
seq_num: i32An incrementing seq number is generated on every precommit token that is returned. Clients should remember the precommit token with the highest sequence number from the current transaction attempt.
Implementations
Sourceimpl MultiplexedSessionPrecommitToken
impl MultiplexedSessionPrecommitToken
Sourcepub fn set_precommit_token<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_precommit_token<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of precommit_token.
Sourcepub fn set_seq_num<T: Into<i32>>(self, v: T) -> Self
pub fn set_seq_num<T: Into<i32>>(self, v: T) -> Self
Sets the value of seq_num.