PartitionReadRequest

Struct PartitionReadRequest 

#[non_exhaustive]
pub struct PartitionReadRequest { pub session: String, pub transaction: Option<TransactionSelector>, pub table: String, pub index: String, pub columns: Vec<String>, pub key_set: Option<KeySet>, pub partition_options: Option<PartitionOptions>, /* private fields */ }
The request for PartitionRead

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The session used to create the partitions.

transaction: Option<TransactionSelector>

Read only snapshot transactions are supported, read/write and single use transactions are not.

table: String

Required. The name of the table in the database to be read.

index: String

If non-empty, the name of an index on table. This index is used instead of the table primary key when interpreting key_set and sorting result rows. See key_set for further information.

columns: Vec<String>

The columns of table to be returned for each row matching this request.

key_set: Option<KeySet>

Required. key_set identifies the rows to be yielded. key_set names the primary keys of the rows in table to be yielded, unless index is present. If index is present, then key_set instead names index keys in index.

It isn’t an error for the key_set to name rows that don’t exist in the database. Read yields nothing for nonexistent rows.

partition_options: Option<PartitionOptions>

Additional options that affect how many partitions are created.

Implementations

Source

impl PartitionReadRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

pub fn set_transaction<T>(self, v: T) -> Self

Sets the value of transaction.

pub fn set_or_clear_transaction<T>(self, v: Option<T>) -> Self

Sets or clears the value of transaction.

pub fn set_table<T: Into<String>>(self, v: T) -> Self

Sets the value of table.

pub fn set_index<T: Into<String>>(self, v: T) -> Self

Sets the value of index.

pub fn set_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of columns.

pub fn set_key_set<T>(self, v: T) -> Self
where T: Into<KeySet>,

Sets the value of key_set.

pub fn set_or_clear_key_set<T>(self, v: Option<T>) -> Self
where T: Into<KeySet>,

Sets or clears the value of key_set.

pub fn set_partition_options<T>(self, v: T) -> Self

Sets the value of partition_options.

pub fn set_or_clear_partition_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of partition_options.