#[non_exhaustive]pub struct PlanNode {
pub index: i32,
pub kind: Kind,
pub display_name: String,
pub child_links: Vec<ChildLink>,
pub short_representation: Option<ShortRepresentation>,
pub metadata: Option<Struct>,
pub execution_stats: Option<Struct>,
/* private fields */
}Expand description
Node information for nodes appearing in a QueryPlan.plan_nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: i32The PlanNode’s index in node
list.
kind: KindUsed to determine the type of node. May be needed for visualizing different kinds of nodes differently. For example, If the node is a SCALAR node, it will have a condensed representation which can be used to directly embed a description of the node in its parent.
display_name: StringThe display name for the node.
child_links: Vec<ChildLink>List of child node indexes and their relationship to this parent.
short_representation: Option<ShortRepresentation>Condensed representation for SCALAR nodes.
metadata: Option<Struct>Attributes relevant to the node contained in a group of key-value pairs. For example, a Parameter Reference node could have the following information in its metadata:
{
"parameter_reference": "param1",
"parameter_type": "array"
}execution_stats: Option<Struct>The execution statistics associated with the node, contained in a group of key-value pairs. Only present if the plan was returned as a result of a profile query. For example, number of executions, number of rows/time per execution etc.
Implementations
Sourceimpl PlanNode
impl PlanNode
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Sourcepub fn set_child_links<T, V>(self, v: T) -> Self
pub fn set_child_links<T, V>(self, v: T) -> Self
Sets the value of child_links.
Sourcepub fn set_short_representation<T>(self, v: T) -> Selfwhere
T: Into<ShortRepresentation>,
pub fn set_short_representation<T>(self, v: T) -> Selfwhere
T: Into<ShortRepresentation>,
Sets the value of short_representation.
Sourcepub fn set_or_clear_short_representation<T>(self, v: Option<T>) -> Selfwhere
T: Into<ShortRepresentation>,
pub fn set_or_clear_short_representation<T>(self, v: Option<T>) -> Selfwhere
T: Into<ShortRepresentation>,
Sets or clears the value of short_representation.
Sourcepub fn set_metadata<T>(self, v: T) -> Self
pub fn set_metadata<T>(self, v: T) -> Self
Sets the value of metadata.
Sourcepub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of metadata.
Sourcepub fn set_execution_stats<T>(self, v: T) -> Self
pub fn set_execution_stats<T>(self, v: T) -> Self
Sets the value of execution_stats.
Sourcepub fn set_or_clear_execution_stats<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_execution_stats<T>(self, v: Option<T>) -> Self
Sets or clears the value of execution_stats.