#[non_exhaustive]pub struct ResultSet {
pub metadata: Option<ResultSetMetadata>,
pub rows: Vec<ListValue>,
pub stats: Option<ResultSetStats>,
pub precommit_token: Option<MultiplexedSessionPrecommitToken>,
pub cache_update: Option<CacheUpdate>,
/* private fields */
}Expand description
Results from Read or ExecuteSql.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.metadata: Option<ResultSetMetadata>Metadata about the result set, such as row type information.
rows: Vec<ListValue>Each element in rows is a row whose format is defined by
metadata.row_type. The ith
element in each row matches the ith field in
metadata.row_type. Elements
are encoded based on type as described here.
stats: Option<ResultSetStats>Query plan and execution statistics for the SQL statement that produced this result set. These can be requested by setting ExecuteSqlRequest.query_mode. DML statements always produce stats containing the number of rows modified, unless executed using the ExecuteSqlRequest.QueryMode.PLAN ExecuteSqlRequest.query_mode. Other fields might or might not be populated, based on the ExecuteSqlRequest.query_mode.
precommit_token: Option<MultiplexedSessionPrecommitToken>Optional. A precommit token is included if the read-write transaction is on a multiplexed session. Pass the precommit token with the highest sequence number from this transaction attempt to the Commit request for this transaction.
cache_update: Option<CacheUpdate>Optional. A cache update expresses a set of changes the client should
incorporate into its location cache. The client should discard the changes
if they are older than the data it already has. This data can be obtained
in response to requests that included a RoutingHint field, but may also
be obtained by explicit location-fetching RPCs which may be added in the
future.
Implementations
Sourceimpl ResultSet
impl ResultSet
Sourcepub fn set_metadata<T>(self, v: T) -> Selfwhere
T: Into<ResultSetMetadata>,
pub fn set_metadata<T>(self, v: T) -> Selfwhere
T: Into<ResultSetMetadata>,
Sets the value of metadata.
Sourcepub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResultSetMetadata>,
pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResultSetMetadata>,
Sets or clears the value of metadata.
Sourcepub fn set_stats<T>(self, v: T) -> Selfwhere
T: Into<ResultSetStats>,
pub fn set_stats<T>(self, v: T) -> Selfwhere
T: Into<ResultSetStats>,
Sets the value of stats.
Sourcepub fn set_or_clear_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResultSetStats>,
pub fn set_or_clear_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResultSetStats>,
Sets or clears the value of stats.
Sourcepub fn set_precommit_token<T>(self, v: T) -> Selfwhere
T: Into<MultiplexedSessionPrecommitToken>,
pub fn set_precommit_token<T>(self, v: T) -> Selfwhere
T: Into<MultiplexedSessionPrecommitToken>,
Sets the value of precommit_token.
Sourcepub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Selfwhere
T: Into<MultiplexedSessionPrecommitToken>,
pub fn set_or_clear_precommit_token<T>(self, v: Option<T>) -> Selfwhere
T: Into<MultiplexedSessionPrecommitToken>,
Sets or clears the value of precommit_token.
Sourcepub fn set_cache_update<T>(self, v: T) -> Selfwhere
T: Into<CacheUpdate>,
pub fn set_cache_update<T>(self, v: T) -> Selfwhere
T: Into<CacheUpdate>,
Sets the value of cache_update.
Sourcepub fn set_or_clear_cache_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<CacheUpdate>,
pub fn set_or_clear_cache_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<CacheUpdate>,
Sets or clears the value of cache_update.