#[non_exhaustive]pub struct ResultSetStats {
pub query_plan: Option<QueryPlan>,
pub query_stats: Option<Struct>,
pub row_count: Option<RowCount>,
/* private fields */
}Expand description
Additional statistics about a ResultSet or PartialResultSet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_plan: Option<QueryPlan>QueryPlan for the query associated with this result.
query_stats: Option<Struct>Aggregated statistics from the execution of the query. Only present when the query is profiled. For example, a query could return the statistics as follows:
{
"rows_returned": "3",
"elapsed_time": "1.22 secs",
"cpu_time": "1.19 secs"
}row_count: Option<RowCount>The number of rows modified by the DML statement.
Implementations
Sourceimpl ResultSetStats
impl ResultSetStats
Sourcepub fn set_query_plan<T>(self, v: T) -> Self
pub fn set_query_plan<T>(self, v: T) -> Self
Sets the value of query_plan.
Sourcepub fn set_or_clear_query_plan<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_query_plan<T>(self, v: Option<T>) -> Self
Sets or clears the value of query_plan.
Sourcepub fn set_query_stats<T>(self, v: T) -> Self
pub fn set_query_stats<T>(self, v: T) -> Self
Sets the value of query_stats.
Sourcepub fn set_or_clear_query_stats<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_query_stats<T>(self, v: Option<T>) -> Self
Sets or clears the value of query_stats.
Sourcepub fn set_row_count<T: Into<Option<RowCount>>>(self, v: T) -> Self
pub fn set_row_count<T: Into<Option<RowCount>>>(self, v: T) -> Self
Sets the value of row_count.
Note that all the setters affecting row_count are mutually
exclusive.
Sourcepub fn row_count_exact(&self) -> Option<&i64>
pub fn row_count_exact(&self) -> Option<&i64>
The value of row_count
if it holds a RowCountExact, None if the field is not set or
holds a different branch.
Sourcepub fn set_row_count_exact<T: Into<i64>>(self, v: T) -> Self
pub fn set_row_count_exact<T: Into<i64>>(self, v: T) -> Self
Sets the value of row_count
to hold a RowCountExact.
Note that all the setters affecting row_count are
mutually exclusive.
Sourcepub fn row_count_lower_bound(&self) -> Option<&i64>
pub fn row_count_lower_bound(&self) -> Option<&i64>
The value of row_count
if it holds a RowCountLowerBound, None if the field is not set or
holds a different branch.
Sourcepub fn set_row_count_lower_bound<T: Into<i64>>(self, v: T) -> Self
pub fn set_row_count_lower_bound<T: Into<i64>>(self, v: T) -> Self
Sets the value of row_count
to hold a RowCountLowerBound.
Note that all the setters affecting row_count are
mutually exclusive.