Type

Struct Type 

#[non_exhaustive]
pub struct Type { pub code: TypeCode, pub array_element_type: Option<Box<Type>>, pub struct_type: Option<Box<StructType>>, pub type_annotation: TypeAnnotationCode, pub proto_type_fqn: String, /* private fields */ }
Type indicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
code: TypeCode

Required. The TypeCode for this type.

array_element_type: Option<Box<Type>>

If code == ARRAY, then array_element_type is the type of the array elements.

struct_type: Option<Box<StructType>>

If code == STRUCT, then struct_type provides type information for the struct’s fields.

type_annotation: TypeAnnotationCode

The TypeAnnotationCode that disambiguates SQL type that Spanner will use to represent values of this type during query processing. This is necessary for some type codes because a single TypeCode can be mapped to different SQL types depending on the SQL dialect. type_annotation typically is not needed to process the content of a value (it doesn’t affect serialization) and clients can ignore it on the read path.

proto_type_fqn: String

If code == PROTO or code == ENUM, then proto_type_fqn is the fully qualified name of the proto type representing the proto/enum definition.

Implementations

Source

impl Type

pub fn new() -> Self

Creates a new default instance.

pub fn set_code<T: Into<TypeCode>>(self, v: T) -> Self

Sets the value of code.

pub fn set_array_element_type<T>(self, v: T) -> Self
where T: Into<Type>,

Sets the value of array_element_type.

pub fn set_or_clear_array_element_type<T>(self, v: Option<T>) -> Self
where T: Into<Type>,

Sets or clears the value of array_element_type.

pub fn set_struct_type<T>(self, v: T) -> Self
where T: Into<StructType>,

Sets the value of struct_type.

pub fn set_or_clear_struct_type<T>(self, v: Option<T>) -> Self
where T: Into<StructType>,

Sets or clears the value of struct_type.

pub fn set_type_annotation<T: Into<TypeAnnotationCode>>(self, v: T) -> Self

Sets the value of type_annotation.

pub fn set_proto_type_fqn<T: Into<String>>(self, v: T) -> Self

Sets the value of proto_type_fqn.