Transaction-scoped interfaces and transaction runners. Re-exports for Spanner transactions.
Structs
- Basic
Transaction Retry Policy - Policy for automatically retrying a transaction when it is aborted based on the number of attempts and total elapsed time.
- Multi
UseRead Only Transaction - A multi-use read-only transaction. This transaction can be used for multiple read queries ensuring consistency across all queries.
- Partitioned
DmlTransaction - A Partitioned DML transaction.
- Read
Write Transaction - A read-write transaction.
- Single
UseRead Only Transaction - A single-use read-only transaction. A single-use read-only transaction is the most efficient way to execute a single query or read operation.
- Timestamp
Bound - Use a timestamp bound to specify how to choose a timestamp at which a query should read data.
- Transaction
Runner - A runner for read/write transactions. Aborted transactions are automatically retried.
- Write
Only Transaction - A write-only transaction.
Enums
- Begin
Transaction Option - Options for how to start a transaction.