pub struct PartitionedDmlTransaction { /* private fields */ }Expand description
A Partitioned DML transaction.
Partitioned DML transactions are used to execute a single DML statement that may modify a large number of rows. The execution of the statement will automatically be partitioned into smaller transactions by Spanner, which may execute in parallel.
A Partitioned DML transaction cannot be committed or rolled back.
See also: https://docs.cloud.google.com/spanner/docs/dml-partitioned
Implementations
Sourceimpl PartitionedDmlTransaction
impl PartitionedDmlTransaction
Sourcepub async fn execute_update<T: Into<Statement>>(
self,
statement: T,
) -> Result<i64>
pub async fn execute_update<T: Into<Statement>>( self, statement: T, ) -> Result<i64>
Executes a Partitioned DML statement.
Example
let db_client = spanner.database_client("projects/p/instances/i/databases/d").build().await?;
let transaction = db_client.partitioned_dml_transaction().build().await?;
let statement = Statement::builder("UPDATE users SET active = true WHERE TRUE").build();
let modified_rows = transaction.execute_update(statement).await?;Return
The number of rows that was at least modified by the statement. Note that the actual number of rows that was modified may be higher than this number if the statement was retried or split into multiple transactions by Spanner, and some of these (sub)transactions were executed multiple times.
See also: https://docs.cloud.google.com/spanner/docs/dml-partitioned