Module value

Module value 

Type and value representations and conversion traits.

Structs

List
A lightweight wrapper around a protobuf ListValue.
Struct
A lightweight wrapper around a protobuf Struct.
Type
Spanner type definition.
Value
Value is a transparent wrapper around a protobuf value. It adds helper methods for accessing the underlying value.

Enums

Kind
Kind indicates the type of the value.
TypeCode
Spanner type code.

Traits

FromValue
Converts a Spanner Value into a Rust type.
ToValue
Converts Rust types to Spanner Value.