Value

Struct Value 

pub struct Value(/* private fields */);
Value is a transparent wrapper around a protobuf value. It adds helper methods for accessing the underlying value.

Implementations

Source

impl Value

pub fn kind(&self) -> Kind

Returns the kind of the value.

pub fn try_as_string(&self) -> Option<&str>

Returns the underlying string value if the kind is String.

pub fn as_string(&self) -> &str

Returns the underlying string value. Panics if the kind is not String.

pub fn try_as_bool(&self) -> Option<bool>

Returns the underlying bool value if the kind is Bool.

pub fn as_bool(&self) -> bool

Returns the underlying bool value. Panics if the kind is not Bool.

pub fn try_as_f64(&self) -> Option<f64>

Returns the underlying number value if the kind is Number.

pub fn as_f64(&self) -> f64

Returns the underlying number value. Panics if the kind is not Number.

pub fn try_as_struct(&self) -> Option<&Struct>

Returns the underlying struct value as a map of Values if the kind is Struct.

pub fn as_struct(&self) -> &Struct

Returns the underlying struct value. Panics if the kind is not Struct.

pub fn try_as_list(&self) -> Option<&List>

Returns the underlying list value as a vector of Values if the kind is List.

pub fn as_list(&self) -> &List

Returns the underlying list value. Panics if the kind is not List.